@@ -40,14 +40,10 @@
 
 #endif
 
-/* harmful on Solaris so we delete functionality */
-
-#if (!defined(sun) && !defined(__sun__))
 #include <sys/ioctl.h>
-#endif
-
 #include <unistd.h> 
 #include <fcntl.h>
+#include <time.h>  
 #include <sys/time.h>  
 #include <sys/types.h> 
 #include <sys/socket.h>
@@ -56,6 +52,10 @@
 #include <netinet/in.h> 
 #include <net/if.h>
 
+#if (defined(sun) || defined(__sun__))
+#include <sys/sockio.h>
+#endif
+
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
 /*                           Constants                                    */
 /*________________________________________________________________________*/
@@ -98,6 +98,12 @@
 /* default system parameters */
 /*****************************/
 
+#if defined(__APPLE__)          /* variable-length ifconf */
+#define NSYS_IFCONF_VARLEN 1
+#else
+#define NSYS_IFCONF_VARLEN 0
+#endif
+
 #ifndef SO_BSDCOMPAT
 #define SO_BSDCOMPAT 0
 #endif
@@ -689,7 +695,7 @@
 /*******/
 
 #ifndef NSYS_SIP_IP
-#define NSYS_SIP_IP          "128.32.131.152"
+#define NSYS_SIP_IP          "128.32.112.203"
 #endif
 
 #ifndef NSYS_SIP_RTP_PORT
@@ -765,19 +771,19 @@ extern unsigned char nsys_netout_rtp_packet[];  /* rtp packet out */
 
 /* rtcp packets and lengths */
 
-extern unsigned char * netout_rtcp_packet_bye;
-extern unsigned char * netout_rtcp_packet_rrempty;
-extern unsigned char * netout_rtcp_packet_rr;
-extern unsigned char * netout_rtcp_packet_srempty;
-extern unsigned char * netout_rtcp_packet_sr;
+extern unsigned char * nsys_netout_rtcp_packet_bye;
+extern unsigned char * nsys_netout_rtcp_packet_rrempty;
+extern unsigned char * nsys_netout_rtcp_packet_rr;
+extern unsigned char * nsys_netout_rtcp_packet_srempty;
+extern unsigned char * nsys_netout_rtcp_packet_sr;
 
-extern int netout_rtcp_len_bye;
-extern int netout_rtcp_len_rrempty;
-extern int netout_rtcp_len_rr;
-extern int netout_rtcp_len_srempty;
-extern int netout_rtcp_len_sr;
+extern int nsys_netout_rtcp_len_bye;
+extern int nsys_netout_rtcp_len_rrempty;
+extern int nsys_netout_rtcp_len_rr;
+extern int nsys_netout_rtcp_len_srempty;
+extern int nsys_netout_rtcp_len_sr;
 
-extern char * sdes_typename[];            /* rtcp debug array */
+extern char * nsys_sdes_typename[];            /* rtcp debug array */
 
 extern unsigned long nsys_netout_seqnum;  /* rtp output sequence number */
 extern unsigned long nsys_netout_tstamp;  /* rtp output timestamp */
@@ -787,16 +793,16 @@ extern unsigned char nsys_netout_markbit; /* for setting markerbit */
 /* rtp payload support  */
 /************************/
 
-typedef struct payinfo {
+typedef struct nsys_payinfo {
 
   int pindex;               /* index into nsys_payload_types  */
   unsigned char ptype;      /* RTP payload number */
   char name[16];            /* name of payload    */
   int srate;                /* audio sample rate  */
 
-} payinfo;
+} nsys_payinfo;
 
-extern struct payinfo nsys_payload_types[];
+extern struct nsys_payinfo nsys_payload_types[];
 
 /**************/
 /* rtcp state */
@@ -861,45 +867,45 @@ extern long nsys_buffcnt;
 /* checkpoint management */
 /*************************/
 
-extern unsigned long netout_jsend_checkpoint_seqnum;  /* current checkpoint */
-extern unsigned long netout_jsend_checkpoint_changed; /* 1 if changed */
+extern unsigned long nsys_netout_jsend_checkpoint_seqnum;  /* current checkpoint */
+extern unsigned long nsys_netout_jsend_checkpoint_changed; /* 1 if changed */
 
 /*********************/
 /* S-list management */
 /*********************/
 
-extern unsigned char * netout_jsend_slist[];
-extern int netout_jsend_slist_size;
+extern unsigned char * nsys_netout_jsend_slist[];
+extern int nsys_netout_jsend_slist_size;
 
 /*******************************/
 /* guard journal state machine */
 /*******************************/
 
-extern int netout_jsend_guard_send;    /* flag variable: send guard packet */
-extern int netout_jsend_guard_time;    /* guard packet timer state */
-extern int netout_jsend_guard_next;    /* reload value for timer */
-extern int netout_jsend_guard_ontime;  /* minimum delay time for noteon */ 
-extern int netout_jsend_guard_mintime; /* minimum delay time for (!noteon) */
-extern int netout_jsend_guard_maxtime; /* maximum delay time */ 
+extern int nsys_netout_jsend_guard_send;    /* flag variable: send guard packet */
+extern int nsys_netout_jsend_guard_time;    /* guard packet timer state */
+extern int nsys_netout_jsend_guard_next;    /* reload value for timer */
+extern int nsys_netout_jsend_guard_ontime;  /* minimum delay time for noteon */ 
+extern int nsys_netout_jsend_guard_mintime; /* minimum delay time for (!noteon) */
+extern int nsys_netout_jsend_guard_maxtime; /* maximum delay time */ 
 
 /***************************/
 /* recovery journal header */
 /***************************/
 
-extern unsigned char netout_jsend_header[];    /* journal header */
+extern unsigned char nsys_netout_jsend_header[];    /* journal header */
 
 /**************************/
 /* chanell journal record */
 /**************************/
 
-extern unsigned char netout_jsend_channel[];
-extern unsigned char netout_jsend_channel_size;
+extern unsigned char nsys_netout_jsend_channel[];
+extern unsigned char nsys_netout_jsend_channel_size;
 
 /******************************************/
 /* structure holding sender channel state */
 /******************************************/
 
-typedef struct netout_jsend_state {
+typedef struct nsys_netout_jsend_state {
 
   unsigned char  chan;  /* MIDI channel */
   unsigned short clen;  /* first two bytes of cheader */
@@ -970,15 +976,15 @@ typedef struct netout_jsend_state {
   unsigned char chaptert[NSYS_SM_CT_SIZE]; /* chapter t  */
   unsigned char chapterc[NSYS_SM_CC_SIZE]; /* chapter c  */
   
-} netout_jsend_state;
+} nsys_netout_jsend_state;
 
-extern netout_jsend_state netout_jsend[];
+extern nsys_netout_jsend_state nsys_netout_jsend[];
 
 /********************************************/
 /* structure holding receiver channel state */
 /********************************************/
 
-typedef struct netout_jrecv_state {
+typedef struct nsys_netout_jrecv_state {
 
   /* chapter p */
 
@@ -1013,11 +1019,11 @@ typedef struct netout_jrecv_state {
   /* navigation */
 
   unsigned char chan;
-  struct netout_jrecv_state * next;
+  struct nsys_netout_jrecv_state * next;
 
-} netout_jrecv_state;
+} nsys_netout_jrecv_state;
 
-extern netout_jrecv_state * nsys_recvfree;  /* receiver free list */
+extern nsys_netout_jrecv_state * nsys_recvfree;  /* receiver free list */
 
 /*******/
 /* SIP */
@@ -1057,7 +1063,7 @@ extern int nsys_sipinfo_toggle;                /* RTP/RTCP toggle          */
 /* SSRC stack  */
 /***************/
 
-typedef struct source {
+typedef struct nsys_source {
 
   /* information */
 
@@ -1080,9 +1086,9 @@ typedef struct source {
 
   /* navigation */
 
-  struct source * xtra;               /* if hash clashes */
-  struct source * prev;               /* doubly-linked list */
-  struct source * next;
+  struct nsys_source * xtra;               /* if hash clashes */
+  struct nsys_source * prev;               /* doubly-linked list */
+  struct nsys_source * next;
 
   /* reception statistics */
 
@@ -1122,14 +1128,14 @@ typedef struct source {
   unsigned long last_hiseq_rec;       /* RTCP extended sequence number   */
   unsigned long last_hiseq_ext;       /* local-adjusted RTCP ext seq num */
 
-  struct netout_jrecv_state
+  struct nsys_netout_jrecv_state
   * jrecv[CSYS_MIDI_NUMCHAN];         /* reciever journal state */
 
-} source;
+} nsys_source;
 
-extern struct source * nsys_srcfree;       /* mset ssrc tokens */
-extern struct source * nsys_ssrc[];        /* SSRC hash table  */
-extern struct source * nsys_srcroot;       /* points into nsys_ssrc */
+extern struct nsys_source * nsys_srcfree;       /* mset ssrc tokens */
+extern struct nsys_source * nsys_ssrc[];        /* SSRC hash table  */
+extern struct nsys_source * nsys_srcroot;       /* points into nsys_ssrc */
 
 
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
@@ -1189,12 +1195,12 @@ extern void nsys_netin_redirect(int fd, unsigned char * packet,
 
 extern int nsys_netin_sipaddr(int fd, char * ip, unsigned short port);
 extern int nsys_netin_siporigin(int fd, struct sockaddr_in * addr);
-extern int nsys_netin_make_marray(struct payinfo ** marray, char * media);
-extern int nsys_netin_set_marray(char * line, struct payinfo marray[],
+extern int nsys_netin_make_marray(struct nsys_payinfo ** marray, char * media);
+extern int nsys_netin_set_marray(char * line, struct nsys_payinfo marray[],
 				 int mlen);
 
-extern int nsys_netin_payvalid(struct payinfo marray[], int mlen, int fd);
-extern void nsys_netin_payset(struct source * sptr, struct payinfo marray[],
+extern int nsys_netin_payvalid(struct nsys_payinfo marray[], int mlen, int fd);
+extern void nsys_netin_payset(struct nsys_source * sptr, struct nsys_payinfo marray[],
 			      int mlen);
 extern int nsys_netin_noreplay(char * ip, unsigned short port, 
 			       unsigned long sdp_time);
@@ -1207,29 +1213,29 @@ extern void nsys_sip_shutdown(void);
 extern int nsys_setup(int block);
 extern void nsys_shutdown(void);
 
-extern source * nsys_netin_addsrc(int fd, long ssrc,
+extern nsys_source * nsys_netin_addsrc(int fd, long ssrc,
 				  char * ip, unsigned short port);
-extern int nsys_netin_rtpstats(source * sptr, unsigned char * packet);
+extern int nsys_netin_rtpstats(nsys_source * sptr, unsigned char * packet);
 extern void  nsys_warning(int level, char * message);
 extern void nsys_terminate_error(char * message); 
-extern void nsys_status(source * sptr, char * message);
+extern void nsys_status(nsys_source * sptr, char * message);
 extern int nsys_netin_ptypevalid(unsigned char ptype);
-extern void nsys_netin_ptypeset(struct source * sptr, unsigned char ptype);
-extern netout_jrecv_state * nsys_netin_newrecv(unsigned char chan);
+extern void nsys_netin_ptypeset(struct nsys_source * sptr, unsigned char ptype);
+extern nsys_netout_jrecv_state * nsys_netin_newrecv(unsigned char chan);
 extern char * nsys_find_clientip(char * ip);
 
 /****************/
 /* net_rtcplib.c */
 /****************/
 
-extern source * nsys_netin_rtcp(unsigned char * packet, int len, 
+extern nsys_source * nsys_netin_rtcp(unsigned char * packet, int len, 
 				struct sockaddr_in * ipaddr);
 extern int nsys_make_rtcp(void);
 extern int nsys_make_rtcpbye(void);
 extern void nsys_netout_rtcptime(void);
 extern void nsys_delete_ssrc(unsigned long ssrc, char * reason);
-extern source * nsys_harvest_ssrc(int fd, struct sockaddr_in * ipaddr);
-extern void nsys_late_windowcheck(source * sptr, unsigned long tstamp);
+extern nsys_source * nsys_harvest_ssrc(int fd, struct sockaddr_in * ipaddr);
+extern void nsys_late_windowcheck(nsys_source * sptr, unsigned long tstamp);
 extern char * nsys_netin_newcname(unsigned char * packet, int len);
 extern void nsys_netin_bye(unsigned char * packet, int len);
 extern int nsys_netout_excheck(void);
@@ -1247,7 +1253,7 @@ extern void nsys_netout_rtcp_initsr(unsigned char * p, int len);
 extern void nsys_netout_rtcp_initsdes(unsigned char * p, int len);
 extern void nsys_netout_rtcp_initbye(unsigned char * p);
 extern void nsys_netin_rtcp_trunc(int sub);
-extern void nsys_netin_latenotes_open(source * sptr);
+extern void nsys_netin_latenotes_open(nsys_source * sptr);
 
 /***************/
 /* net_jsend.c */
@@ -1260,98 +1266,98 @@ extern void nsys_netout_journal_addstate(unsigned char cmd,
 extern void nsys_netout_journal_addhistory(unsigned char cmd,
 					   unsigned char ndata,
 					   unsigned char vdata);
-extern void nsys_netin_journal_trimstate(source * lptr);
+extern void nsys_netin_journal_trimstate(nsys_source * lptr);
 extern void nsys_netout_midistate_init(void);
 extern void nsys_netout_guard_tick(void);
 extern void nsys_netout_journal_changecheck(void);
-extern void nsys_netout_journal_addprogram(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addprogram(nsys_netout_jsend_state * jsend, 
 					   unsigned char ndata);
-extern void nsys_netout_journal_addpwheel(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addpwheel(nsys_netout_jsend_state * jsend, 
 					  unsigned char ndata, 
 					  unsigned char vdata);
-extern void nsys_netout_journal_addnoteoff(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addnoteoff(nsys_netout_jsend_state * jsend, 
 					   unsigned char ndata);
-extern void nsys_netout_journal_addnoteon(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addnoteon(nsys_netout_jsend_state * jsend, 
 					  unsigned char ndata, 
 					  unsigned char vdata);
-extern void nsys_netout_journal_addptouch(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addptouch(nsys_netout_jsend_state * jsend, 
 					   unsigned char ndata,
 					   unsigned char vdata);
-extern void nsys_netout_journal_addctouch(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addctouch(nsys_netout_jsend_state * jsend, 
 					  unsigned char ndata);
-extern void nsys_netout_journal_addcontrol(netout_jsend_state * jsend, 
+extern void nsys_netout_journal_addcontrol(nsys_netout_jsend_state * jsend, 
 					   unsigned char ndata,
 					   unsigned char vdata);
 
-extern void nsys_netout_journal_trimchapter(netout_jsend_state * jsend,
+extern void nsys_netout_journal_trimchapter(nsys_netout_jsend_state * jsend,
 					    int channel);
-extern void nsys_netout_journal_trimprogram(netout_jsend_state * jsend);
-extern void nsys_netout_journal_trimpwheel(netout_jsend_state * jsend);
-extern void nsys_netout_journal_trimctouch(netout_jsend_state * jsend);
+extern void nsys_netout_journal_trimprogram(nsys_netout_jsend_state * jsend);
+extern void nsys_netout_journal_trimpwheel(nsys_netout_jsend_state * jsend);
+extern void nsys_netout_journal_trimctouch(nsys_netout_jsend_state * jsend);
 
-extern void nsys_netout_journal_trimallcontrol(netout_jsend_state * jsend);
-extern void nsys_netout_journal_trimpartcontrol(netout_jsend_state * jsend,
+extern void nsys_netout_journal_trimallcontrol(nsys_netout_jsend_state * jsend);
+extern void nsys_netout_journal_trimpartcontrol(nsys_netout_jsend_state * jsend,
 						unsigned long minseq);
-extern void nsys_netout_journal_trimallptouch(netout_jsend_state * jsend);
-extern void nsys_netout_journal_trimpartptouch(netout_jsend_state * jsend,
+extern void nsys_netout_journal_trimallptouch(nsys_netout_jsend_state * jsend);
+extern void nsys_netout_journal_trimpartptouch(nsys_netout_jsend_state * jsend,
 						unsigned long minseq);
-extern void nsys_netout_journal_trimallnote(netout_jsend_state * jsend);
-extern void nsys_netout_journal_trimpartnote(netout_jsend_state * jsend,
+extern void nsys_netout_journal_trimallnote(nsys_netout_jsend_state * jsend);
+extern void nsys_netout_journal_trimpartnote(nsys_netout_jsend_state * jsend,
 					     unsigned long minseq);
 
 /**************/
 /* net_recv.c */
 /**************/
 
-extern int nsys_netin_journal_recovery(source * sptr, int rtpcode, 
+extern int nsys_netin_journal_recovery(nsys_source * sptr, int rtpcode, 
 				       unsigned char * packet, int numbytes,
 				       unsigned char * buff, long * fill,
 				       long size);
 
-extern void nsys_netin_journal_trackstate(source * sptr, unsigned char cmd,
+extern void nsys_netin_journal_trackstate(nsys_source * sptr, unsigned char cmd,
 					  unsigned char ndata, 
 					  unsigned char vdata);
 
-extern int nsys_netin_journal_addcmd(source * sptr, unsigned char * buff, 
+extern int nsys_netin_journal_addcmd(nsys_source * sptr, unsigned char * buff, 
 				     long * fill, long size,
 				     unsigned char cmd, unsigned char ndata,
 				     unsigned char vdata);
 
-extern int nsys_netin_jrec_program(source * sptr, unsigned char * p,
-				   netout_jrecv_state * jrecv,
+extern int nsys_netin_jrec_program(nsys_source * sptr, unsigned char * p,
+				   nsys_netout_jrecv_state * jrecv,
 				   unsigned char * buff,  
 				   long * fill, long size);
 
-extern int nsys_netin_jrec_wheel(source * sptr, unsigned char * p,
-				 netout_jrecv_state * jrecv,
+extern int nsys_netin_jrec_wheel(nsys_source * sptr, unsigned char * p,
+				 nsys_netout_jrecv_state * jrecv,
 				 unsigned char * buff,  
 				 long * fill, long size);
 
-extern int nsys_netin_jrec_notelog(source * sptr, unsigned char * p,
-				   netout_jrecv_state * jrecv, 
+extern int nsys_netin_jrec_notelog(nsys_source * sptr, unsigned char * p,
+				   nsys_netout_jrecv_state * jrecv, 
 				   unsigned char many,
 				   short loglen, unsigned char * checkptr,
 				   unsigned char * buff, 
 				   long * fill, long size);
 
-extern int nsys_netin_jrec_bitfield(source * sptr, unsigned char * p,
-				    netout_jrecv_state * jrecv, 
+extern int nsys_netin_jrec_bitfield(nsys_source * sptr, unsigned char * p,
+				    nsys_netout_jrecv_state * jrecv, 
 				    unsigned char low, unsigned char high,
 				    unsigned char * buff, long * fill,
 				    long size);
 
-extern int nsys_netin_jrec_ptouch(source * sptr, unsigned char * p,
-				  netout_jrecv_state * jrecv, short loglen,
+extern int nsys_netin_jrec_ptouch(nsys_source * sptr, unsigned char * p,
+				  nsys_netout_jrecv_state * jrecv, short loglen,
 				  unsigned char many, unsigned char * buff, 
 				  long * fill, long size);
 
-extern int nsys_netin_jrec_ctouch(source * sptr, unsigned char * p,
-				  netout_jrecv_state * jrecv,
+extern int nsys_netin_jrec_ctouch(nsys_source * sptr, unsigned char * p,
+				  nsys_netout_jrecv_state * jrecv,
 				  unsigned char * buff,  
 				  long * fill, long size);
 
-extern int nsys_netin_jrec_control(source * sptr, unsigned char * p,
-				   netout_jrecv_state * jrecv, short loglen,
+extern int nsys_netin_jrec_control(nsys_source * sptr, unsigned char * p,
+				   nsys_netout_jrecv_state * jrecv, short loglen,
 				   unsigned char many, unsigned char * buff, 
 				   long * fill, long size);
 
