@@ -35,13 +35,13 @@
 /*          main routine for parsing recovery journal           */
 /****************************************************************/
 
-int nsys_netin_journal_recovery(source * sptr, int rtpcode, 
+int nsys_netin_journal_recovery(nsys_source * sptr, int rtpcode, 
 				unsigned char * packet,
 				int numbytes, unsigned char * buff,  
 				long * fill, long size)
 
 {
-  netout_jrecv_state * jrecv;
+  nsys_netout_jrecv_state * jrecv;
   int numchan, bflag, i, j;
   short chanlen, loglen;
   unsigned char chapters, chan, low, high, many;
@@ -244,11 +244,11 @@ int nsys_netin_journal_recovery(source * sptr, int rtpcode,
 /*            receiver state: add a new MIDI event              */
 /****************************************************************/
 
-void nsys_netin_journal_trackstate(source * sptr, unsigned char cmd,
+void nsys_netin_journal_trackstate(nsys_source * sptr, unsigned char cmd,
 				   unsigned char ndata, unsigned char vdata)
 
 {
-  netout_jrecv_state * jrecv;
+  nsys_netout_jrecv_state * jrecv;
 
   if ((jrecv = sptr->jrecv[cmd & 0x0F]) == NULL)
     jrecv = sptr->jrecv[cmd & 0x0F] = nsys_netin_newrecv(cmd & 0x0F);
@@ -332,8 +332,8 @@ void nsys_netin_journal_trackstate(source * sptr, unsigned char cmd,
 /****************************************************************/
 
 
-int nsys_netin_jrec_program(source * sptr, unsigned char * p,
-			  netout_jrecv_state * jrecv,
+int nsys_netin_jrec_program(nsys_source * sptr, unsigned char * p,
+			  nsys_netout_jrecv_state * jrecv,
 			  unsigned char * buff,  
 			  long * fill, long size)
 
@@ -418,8 +418,8 @@ int nsys_netin_jrec_program(source * sptr, unsigned char * p,
 /****************************************************************/
 
 
-int nsys_netin_jrec_wheel(source * sptr, unsigned char * p,
-			  netout_jrecv_state * jrecv,
+int nsys_netin_jrec_wheel(nsys_source * sptr, unsigned char * p,
+			  nsys_netout_jrecv_state * jrecv,
 			  unsigned char * buff,  
 			  long * fill, long size)
 
@@ -455,8 +455,8 @@ int nsys_netin_jrec_wheel(source * sptr, unsigned char * p,
 /*               process Note Logs of chapter N                 */
 /****************************************************************/
 
-int nsys_netin_jrec_notelog(source * sptr, unsigned char * p,
-			    netout_jrecv_state * jrecv, unsigned char many, 
+int nsys_netin_jrec_notelog(nsys_source * sptr, unsigned char * p,
+			    nsys_netout_jrecv_state * jrecv, unsigned char many, 
 			    short loglen, unsigned char * checkptr,
 			    unsigned char * buff, 
 			    long * fill, long size)
@@ -590,8 +590,8 @@ int nsys_netin_jrec_notelog(source * sptr, unsigned char * p,
 /*               process bitfields of chapter N                */
 /****************************************************************/
 
-int nsys_netin_jrec_bitfield(source * sptr, unsigned char * p,
-			     netout_jrecv_state * jrecv, unsigned char low, 
+int nsys_netin_jrec_bitfield(nsys_source * sptr, unsigned char * p,
+			     nsys_netout_jrecv_state * jrecv, unsigned char low, 
 			     unsigned char high, unsigned char * buff, 
 			     long * fill, long size)
 {
@@ -643,8 +643,8 @@ int nsys_netin_jrec_bitfield(source * sptr, unsigned char * p,
 /*               process chapter P (poly touch)                 */
 /****************************************************************/
 
-int nsys_netin_jrec_ptouch(source * sptr, unsigned char * p,
-			   netout_jrecv_state * jrecv, short loglen,
+int nsys_netin_jrec_ptouch(nsys_source * sptr, unsigned char * p,
+			   nsys_netout_jrecv_state * jrecv, short loglen,
 			   unsigned char many, unsigned char * buff, 
 			   long * fill, long size)
 
@@ -687,8 +687,8 @@ int nsys_netin_jrec_ptouch(source * sptr, unsigned char * p,
 /*               process chapter T (channel touch)              */
 /****************************************************************/
 
-int nsys_netin_jrec_ctouch(source * sptr, unsigned char * p,
-			   netout_jrecv_state * jrecv,
+int nsys_netin_jrec_ctouch(nsys_source * sptr, unsigned char * p,
+			   nsys_netout_jrecv_state * jrecv,
 			   unsigned char * buff,  
 			   long * fill, long size)
 
@@ -719,8 +719,8 @@ int nsys_netin_jrec_ctouch(source * sptr, unsigned char * p,
 /*               process chapter C (controllers)                */
 /****************************************************************/
 
-int nsys_netin_jrec_control(source * sptr, unsigned char * p,
-			   netout_jrecv_state * jrecv, short loglen,
+int nsys_netin_jrec_control(nsys_source * sptr, unsigned char * p,
+			   nsys_netout_jrecv_state * jrecv, short loglen,
 			   unsigned char many, unsigned char * buff, 
 			   long * fill, long size)
 
@@ -785,7 +785,7 @@ int nsys_netin_jrec_control(source * sptr, unsigned char * p,
 /*           adds a new MIDI command to the buffer              */
 /****************************************************************/
 
-int nsys_netin_journal_addcmd(source * sptr, unsigned char * buff, 
+int nsys_netin_journal_addcmd(nsys_source * sptr, unsigned char * buff, 
 			      long * fill, long size,
 			      unsigned char cmd, unsigned char ndata,
 			      unsigned char vdata)
