@@ -38,13 +38,13 @@ int nsys_netin_journal_create(unsigned char * packet, int len)
 {
   unsigned char * p = packet;
   int i, j, channel;
-  netout_jsend_state * jsend;
+  nsys_netout_jsend_state * jsend;
 
   /********************************/
   /* add journal header to packet */
   /********************************/
 
-  memcpy(p, netout_jsend_header, NSYS_SM_JH_SIZE);
+  memcpy(p, nsys_netout_jsend_header, NSYS_SM_JH_SIZE);
   p += NSYS_SM_JH_SIZE;
   len -= NSYS_SM_JH_SIZE;
 
@@ -52,9 +52,9 @@ int nsys_netin_journal_create(unsigned char * packet, int len)
   /* add chapter(s) if needed */
   /****************************/
 
-  for (channel = 0; channel < netout_jsend_channel_size; channel++)
+  for (channel = 0; channel < nsys_netout_jsend_channel_size; channel++)
     {
-      jsend = &(netout_jsend[netout_jsend_channel[channel]]);
+      jsend = &(nsys_netout_jsend[nsys_netout_jsend_channel[channel]]);
 
       if (jsend->cheader_seqnum)
 	{	  
@@ -186,8 +186,8 @@ int nsys_netin_journal_create(unsigned char * packet, int len)
   /* set S flags  */
   /****************/
 
-  while (netout_jsend_slist_size > 0)
-    *(netout_jsend_slist[--netout_jsend_slist_size]) |= NSYS_SM_SETS; 
+  while (nsys_netout_jsend_slist_size > 0)
+    *(nsys_netout_jsend_slist[--nsys_netout_jsend_slist_size]) |= NSYS_SM_SETS; 
 
   return (p - packet);
 }
@@ -201,35 +201,35 @@ void nsys_netout_journal_addstate(unsigned char cmd, unsigned char ndata,
 
 {
   unsigned char chan = 0x0F & cmd;
-  netout_jsend_state * jsend;
+  nsys_netout_jsend_state * jsend;
 
-  netout_jsend_guard_send = 0;
+  nsys_netout_jsend_guard_send = 0;
 
-  if (netout_jsend_checkpoint_changed)
+  if (nsys_netout_jsend_checkpoint_changed)
     {
-      netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] &= NSYS_SM_JH_CLRK;
-      netout_jsend_checkpoint_changed = 0;
+      nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] &= NSYS_SM_JH_CLRK;
+      nsys_netout_jsend_checkpoint_changed = 0;
     }
   if ((cmd &= 0xF0) == CSYS_MIDI_NOOP)
     {
-      netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_SETS;
+      nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_SETS;
       return;
     }
   
-  netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] &= NSYS_SM_CLRS;
-  jsend = &(netout_jsend[chan]);
+  nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] &= NSYS_SM_CLRS;
+  jsend = &(nsys_netout_jsend[chan]);
 
   if (jsend->cheader_seqnum == 0)
     {  
-      netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] = ((unsigned char)
-						   netout_jsend_channel_size);
-      netout_jsend_channel[netout_jsend_channel_size++] = chan;
+      nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] = ((unsigned char)
+						   nsys_netout_jsend_channel_size);
+      nsys_netout_jsend_channel[nsys_netout_jsend_channel_size++] = chan;
       jsend->clen = ((((unsigned short)chan) << (NSYS_SM_CH_CHANSHIFT + 8)) |
 		     NSYS_SM_CH_SIZE);
     }
 
   jsend->cheader_seqnum = nsys_netout_seqnum;
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->cheader[NSYS_SM_CH_LOC_FLAGS]);
 
   switch (cmd) {
@@ -269,14 +269,14 @@ void nsys_netout_journal_addhistory(unsigned char cmd, unsigned char ndata,
 
 {
   unsigned char chan = 0x0F & cmd;
-  netout_jsend_state * jsend;
+  nsys_netout_jsend_state * jsend;
 
   cmd &= 0xF0;
 
   if ((cmd != CSYS_MIDI_PROGRAM) && (cmd != CSYS_MIDI_CC))
     return;
   
-  jsend = &(netout_jsend[chan]);
+  jsend = &(nsys_netout_jsend[chan]);
 
   if (jsend->history_active == 0)
     jsend->history_active = 1;
@@ -310,14 +310,14 @@ void nsys_netout_journal_addhistory(unsigned char cmd, unsigned char ndata,
 /*    sender state:  trim journal, update checkpoint packet     */
 /****************************************************************/
 
-void nsys_netin_journal_trimstate(source * lptr)
+void nsys_netin_journal_trimstate(nsys_source * lptr)
 
 { 
   unsigned long minseq;
-  source * minsource;
-  source * sptr;
+  nsys_source * minsource;
+  nsys_source * sptr;
   int channel;
-  netout_jsend_state * jsend;
+  nsys_netout_jsend_state * jsend;
 
   /********************************************/
   /* localize extension to new last_hiseq_ext */
@@ -357,22 +357,22 @@ void nsys_netin_journal_trimstate(source * lptr)
   /***************************************/
 
   if ((minseq == NSYS_RTPSEQ_HIGHEST) || 
-      (minseq == netout_jsend_checkpoint_seqnum))
+      (minseq == nsys_netout_jsend_checkpoint_seqnum))
     return;
 
   /**********************/
   /* update checkpoint  */
   /**********************/
 
-  netout_jsend_checkpoint_seqnum = minseq;
+  nsys_netout_jsend_checkpoint_seqnum = minseq;
   nsys_netout_journal_changecheck();
 
-  if (netout_jsend_channel_size == 0)
+  if (nsys_netout_jsend_channel_size == 0)
     return;
 
-  for (channel = netout_jsend_channel_size - 1; channel >= 0; channel--)
+  for (channel = nsys_netout_jsend_channel_size - 1; channel >= 0; channel--)
     {
-      jsend = &(netout_jsend[netout_jsend_channel[channel]]);
+      jsend = &(nsys_netout_jsend[nsys_netout_jsend_channel[channel]]);
 
       /*******************************/
       /* drop entire channel, or ... */
@@ -382,7 +382,7 @@ void nsys_netin_journal_trimstate(source * lptr)
 	{
 	  nsys_netout_journal_trimchapter(jsend, channel);
 
-	  if (netout_jsend_channel_size)
+	  if (nsys_netout_jsend_channel_size)
 	    continue;
 	  else
 	    break;
@@ -427,19 +427,19 @@ void nsys_netin_journal_trimstate(source * lptr)
   /* housekeeping */
   /****************/
 
-  if (netout_jsend_channel_size == 0)
+  if (nsys_netout_jsend_channel_size == 0)
     {
-      netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_JH_SETA;
-      netout_jsend_slist_size =  0;
+      nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_JH_SETA;
+      nsys_netout_jsend_slist_size =  0;
 
       /* uncomment to disable keep-alive empty-journal RTP packets */ 
-      /* netout_jsend_guard_time = netout_jsend_guard_send = 0;    */
+      /* nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_send = 0;    */
     }
   else
     {
-      netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] &= (~NSYS_SM_JH_CHANMASK);
-      netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= 
-	(unsigned char)(netout_jsend_channel_size - 1);
+      nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] &= (~NSYS_SM_JH_CHANMASK);
+      nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= 
+	(unsigned char)(nsys_netout_jsend_channel_size - 1);
     }
   
 }
@@ -454,12 +454,12 @@ void nsys_netout_guard_tick(void)
 {
   /* enable conditional to disable keep-alive empty-journal RTP packets */
 
-  if (1 || netout_jsend_channel_size)
+  if (1 || nsys_netout_jsend_channel_size)
     {
-      netout_jsend_guard_send = 1;
-      netout_jsend_guard_time = netout_jsend_guard_next;
-      if ((netout_jsend_guard_next <<= 1) > netout_jsend_guard_maxtime)
-	netout_jsend_guard_next = netout_jsend_guard_maxtime;
+      nsys_netout_jsend_guard_send = 1;
+      nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_next;
+      if ((nsys_netout_jsend_guard_next <<= 1) > nsys_netout_jsend_guard_maxtime)
+	nsys_netout_jsend_guard_next = nsys_netout_jsend_guard_maxtime;
     }
 }
 
@@ -471,9 +471,9 @@ void nsys_netout_guard_tick(void)
 void nsys_netout_midistate_init(void)
 
 {
-  int slist_size = netout_jsend_slist_size;
+  int slist_size = nsys_netout_jsend_slist_size;
   unsigned long seqsafe;
-  netout_jsend_state * jsend;
+  nsys_netout_jsend_state * jsend;
   unsigned char i, cmd, ndata, vdata, bankc, bankf;
 
 
@@ -488,7 +488,7 @@ void nsys_netout_midistate_init(void)
 
   for (i = 0; i < CSYS_MIDI_NUMCHAN; i++)
     {
-      jsend = &(netout_jsend[i]);
+      jsend = &(nsys_netout_jsend[i]);
 
       if (jsend->history_active == 0)
 	continue;
@@ -558,22 +558,22 @@ void nsys_netout_midistate_init(void)
 	  nsys_netout_journal_addstate(cmd, ndata, vdata);
 	}
 
-      while (netout_jsend_slist_size > slist_size)
-	*(netout_jsend_slist[--netout_jsend_slist_size]) |= NSYS_SM_SETS;
+      while (nsys_netout_jsend_slist_size > slist_size)
+	*(nsys_netout_jsend_slist[--nsys_netout_jsend_slist_size]) |= NSYS_SM_SETS;
 
     }
 
   if (slist_size == 0)
-    netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_SETS;
+    nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_SETS;
   
   while (slist_size > 0)
-    *(netout_jsend_slist[--slist_size]) &= NSYS_SM_CLRS;
+    *(nsys_netout_jsend_slist[--slist_size]) &= NSYS_SM_CLRS;
 
   nsys_netout_seqnum = seqsafe;   /* restore nsys_netout_seqnum */
 
-  netout_jsend_guard_send = 1;    
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_send = 1;    
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 }
 
@@ -586,7 +586,7 @@ void nsys_netout_midistate_init(void)
 /*               add MIDI Program Change chapter                */
 /****************************************************************/
 
-void nsys_netout_journal_addprogram(netout_jsend_state * jsend, 
+void nsys_netout_journal_addprogram(nsys_netout_jsend_state * jsend, 
 				    unsigned char ndata)
 
 {
@@ -596,7 +596,7 @@ void nsys_netout_journal_addprogram(netout_jsend_state * jsend,
     
   nsys_netout_journal_addhistory(CSYS_MIDI_PROGRAM | jsend->chan, ndata, 0);
 
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->chapterp[NSYS_SM_CP_LOC_PROGRAM]);
   
   if (jsend->chapterp_seqnum)
@@ -610,8 +610,8 @@ void nsys_netout_journal_addprogram(netout_jsend_state * jsend,
     }
   jsend->chapterp_seqnum = nsys_netout_seqnum;
 
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 
 }
@@ -620,14 +620,14 @@ void nsys_netout_journal_addprogram(netout_jsend_state * jsend,
 /*               add MIDI Pitch Wheel chapter                   */
 /****************************************************************/
 
-void nsys_netout_journal_addpwheel(netout_jsend_state * jsend, 
+void nsys_netout_journal_addpwheel(nsys_netout_jsend_state * jsend, 
 				unsigned char ndata, unsigned char vdata)
 
 {
   jsend->chapterw[NSYS_SM_CW_LOC_FIRST] = ndata;
   jsend->chapterw[NSYS_SM_CW_LOC_SECOND] = vdata;
 
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->chapterw[NSYS_SM_CW_LOC_FIRST]);
   
   if (jsend->chapterw_seqnum)
@@ -641,8 +641,8 @@ void nsys_netout_journal_addpwheel(netout_jsend_state * jsend,
     }
   jsend->chapterw_seqnum = nsys_netout_seqnum;
 
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 }
 
@@ -650,7 +650,7 @@ void nsys_netout_journal_addpwheel(netout_jsend_state * jsend,
 /*                  add MIDI NoteOff chapter                    */
 /****************************************************************/
 
-void nsys_netout_journal_addnoteoff(netout_jsend_state * jsend, 
+void nsys_netout_journal_addnoteoff(nsys_netout_jsend_state * jsend, 
 				 unsigned char ndata)
 
 {
@@ -749,7 +749,7 @@ void nsys_netout_journal_addnoteoff(netout_jsend_state * jsend,
   /*****************/
   
   jsend->chaptern[NSYS_SM_CN_LOC_LENGTH] &= NSYS_SM_CLRS; 
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->chaptern[NSYS_SM_CN_LOC_LENGTH]);
   
   /******************************************************************/
@@ -765,8 +765,8 @@ void nsys_netout_journal_addnoteoff(netout_jsend_state * jsend,
   jsend->chaptern_seqarray[ndata] = nsys_netout_seqnum;
   jsend->chaptern_seqnum = nsys_netout_seqnum;
 
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 
 }
@@ -775,7 +775,7 @@ void nsys_netout_journal_addnoteoff(netout_jsend_state * jsend,
 /*               add MIDI NoteOn chapter                   */
 /****************************************************************/
 
-void nsys_netout_journal_addnoteon(netout_jsend_state * jsend, 
+void nsys_netout_journal_addnoteon(nsys_netout_jsend_state * jsend, 
 				   unsigned char ndata, unsigned char vdata)
 
 {
@@ -877,10 +877,10 @@ void nsys_netout_journal_addnoteon(netout_jsend_state * jsend,
   jsend->chaptern_seqarray[ndata] = nsys_netout_seqnum;
   jsend->chaptern_seqnum = nsys_netout_seqnum;
 
-  if (netout_jsend_guard_ontime)
+  if (nsys_netout_jsend_guard_ontime)
     {
-      netout_jsend_guard_time = netout_jsend_guard_ontime;
-      netout_jsend_guard_next = netout_jsend_guard_mintime;
+      nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_ontime;
+      nsys_netout_jsend_guard_next = nsys_netout_jsend_guard_mintime;
     }
 }
 
@@ -888,7 +888,7 @@ void nsys_netout_journal_addnoteon(netout_jsend_state * jsend,
 /*                  add MIDI Poly Touch chapter                 */
 /****************************************************************/
 
-void nsys_netout_journal_addptouch(netout_jsend_state * jsend, 
+void nsys_netout_journal_addptouch(nsys_netout_jsend_state * jsend, 
 				    unsigned char ndata,
 				    unsigned char vdata)
 
@@ -946,15 +946,15 @@ void nsys_netout_journal_addptouch(netout_jsend_state * jsend,
   /* update slists */
   /*****************/
   
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->chaptera[NSYS_SM_CA_LOC_LENGTH]);
   jsend->chaptera_sset = 1;
   
   jsend->chaptera_seqarray[ndata] = nsys_netout_seqnum;
   jsend->chaptera_seqnum = nsys_netout_seqnum;
 
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 }
 
@@ -963,13 +963,13 @@ void nsys_netout_journal_addptouch(netout_jsend_state * jsend,
 /*                  add MIDI Channel Touch chapter              */
 /****************************************************************/
 
-void nsys_netout_journal_addctouch(netout_jsend_state * jsend, 
+void nsys_netout_journal_addctouch(nsys_netout_jsend_state * jsend, 
 				 unsigned char ndata)
 
 {
   jsend->chaptert[NSYS_SM_CT_LOC_PRESSURE] = ndata;
 
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->chaptert[NSYS_SM_CT_LOC_PRESSURE]);
   
   if (jsend->chaptert_seqnum)
@@ -984,8 +984,8 @@ void nsys_netout_journal_addctouch(netout_jsend_state * jsend,
   
   jsend->chaptert_seqnum = nsys_netout_seqnum;
 
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 }
 
@@ -994,7 +994,7 @@ void nsys_netout_journal_addctouch(netout_jsend_state * jsend,
 /*                  add MIDI Controller chapter                */
 /****************************************************************/
 
-void nsys_netout_journal_addcontrol(netout_jsend_state * jsend, 
+void nsys_netout_journal_addcontrol(nsys_netout_jsend_state * jsend, 
 				    unsigned char ndata,
 				    unsigned char vdata)
 
@@ -1092,15 +1092,15 @@ void nsys_netout_journal_addcontrol(netout_jsend_state * jsend,
   /* update slists */
   /*****************/
   
-  netout_jsend_slist[netout_jsend_slist_size++] = 
+  nsys_netout_jsend_slist[nsys_netout_jsend_slist_size++] = 
     &(jsend->chapterc[NSYS_SM_CC_LOC_LENGTH]);
   jsend->chapterc_sset = 1;
   
   jsend->chapterc_seqarray[ndata] = nsys_netout_seqnum;
   jsend->chapterc_seqnum = nsys_netout_seqnum;
 
-  netout_jsend_guard_time = netout_jsend_guard_mintime;
-  netout_jsend_guard_next = (netout_jsend_guard_mintime << 
+  nsys_netout_jsend_guard_time = nsys_netout_jsend_guard_mintime;
+  nsys_netout_jsend_guard_next = (nsys_netout_jsend_guard_mintime << 
 			     (nsys_feclevel == NSYS_SM_FEC_MINIMAL));
 }
 
@@ -1113,7 +1113,7 @@ void nsys_netout_journal_addcontrol(netout_jsend_state * jsend,
 /*                  trim entire chapter                         */
 /****************************************************************/
 
-void nsys_netout_journal_trimchapter(netout_jsend_state * jsend, 
+void nsys_netout_journal_trimchapter(nsys_netout_jsend_state * jsend, 
 				     int channel)
 
 {
@@ -1167,10 +1167,10 @@ void nsys_netout_journal_trimchapter(netout_jsend_state * jsend,
   jsend->chaptern_sset = 0;
   jsend->chaptern_timernum = 0;
 
-  if (channel < (--netout_jsend_channel_size))
-    memmove(&(netout_jsend_channel[channel]), 
-	    &(netout_jsend_channel[channel+1]),
-	    sizeof(unsigned char)* (netout_jsend_channel_size -
+  if (channel < (--nsys_netout_jsend_channel_size))
+    memmove(&(nsys_netout_jsend_channel[channel]), 
+	    &(nsys_netout_jsend_channel[channel+1]),
+	    sizeof(unsigned char)* (nsys_netout_jsend_channel_size -
 				    channel));
 
 }
@@ -1179,7 +1179,7 @@ void nsys_netout_journal_trimchapter(netout_jsend_state * jsend,
 /*                 trim program change chapter                  */
 /****************************************************************/
 
-void nsys_netout_journal_trimprogram(netout_jsend_state * jsend) 
+void nsys_netout_journal_trimprogram(nsys_netout_jsend_state * jsend) 
  
 {
   jsend->chapterp_seqnum = 0;
@@ -1191,7 +1191,7 @@ void nsys_netout_journal_trimprogram(netout_jsend_state * jsend)
 /*                 trim pitch wheel chapter                  */
 /****************************************************************/
 
-void nsys_netout_journal_trimpwheel(netout_jsend_state * jsend) 
+void nsys_netout_journal_trimpwheel(nsys_netout_jsend_state * jsend) 
  
 {
   jsend->chapterw_seqnum = 0;
@@ -1203,7 +1203,7 @@ void nsys_netout_journal_trimpwheel(netout_jsend_state * jsend)
 /*                 trim channel touch chapter                   */
 /****************************************************************/
 
-void nsys_netout_journal_trimctouch(netout_jsend_state * jsend) 
+void nsys_netout_journal_trimctouch(nsys_netout_jsend_state * jsend) 
  
 {
   jsend->chaptert_seqnum = 0;
@@ -1215,7 +1215,7 @@ void nsys_netout_journal_trimctouch(netout_jsend_state * jsend)
 /*                 trim entire controller chapter               */
 /****************************************************************/
 
-void nsys_netout_journal_trimallcontrol(netout_jsend_state * jsend) 
+void nsys_netout_journal_trimallcontrol(nsys_netout_jsend_state * jsend) 
  
 {
   int i, j;
@@ -1237,7 +1237,7 @@ void nsys_netout_journal_trimallcontrol(netout_jsend_state * jsend)
 /*                 partially trim controller chapter            */
 /****************************************************************/
 
-void nsys_netout_journal_trimpartcontrol(netout_jsend_state * jsend, 
+void nsys_netout_journal_trimpartcontrol(nsys_netout_jsend_state * jsend, 
 					 unsigned long minseq)
 
 {
@@ -1269,7 +1269,7 @@ void nsys_netout_journal_trimpartcontrol(netout_jsend_state * jsend,
 /*                 trim entire poly touch chapter               */
 /****************************************************************/
 
-void nsys_netout_journal_trimallptouch(netout_jsend_state * jsend) 
+void nsys_netout_journal_trimallptouch(nsys_netout_jsend_state * jsend) 
  
 {
   int i, j;
@@ -1291,7 +1291,7 @@ void nsys_netout_journal_trimallptouch(netout_jsend_state * jsend)
 /*                 partially trim poly touch chapter            */
 /****************************************************************/
 
-void nsys_netout_journal_trimpartptouch(netout_jsend_state * jsend, 
+void nsys_netout_journal_trimpartptouch(nsys_netout_jsend_state * jsend, 
 					unsigned long minseq)
 
 {
@@ -1323,7 +1323,7 @@ void nsys_netout_journal_trimpartptouch(netout_jsend_state * jsend,
 /*                 trim entire note chapter                     */
 /****************************************************************/
 
-void nsys_netout_journal_trimallnote(netout_jsend_state * jsend) 
+void nsys_netout_journal_trimallnote(nsys_netout_jsend_state * jsend) 
  
 {
   int i, j, k;
@@ -1359,7 +1359,7 @@ void nsys_netout_journal_trimallnote(netout_jsend_state * jsend)
 /*                 trim entire note chapter                     */
 /****************************************************************/
 
-void nsys_netout_journal_trimpartnote(netout_jsend_state * jsend, 
+void nsys_netout_journal_trimpartnote(nsys_netout_jsend_state * jsend, 
 				      unsigned long minseq)
 
 {
@@ -1448,11 +1448,11 @@ void nsys_netout_journal_changecheck(void)
 {
   unsigned short check_seqnum_net;
 
-  netout_jsend_checkpoint_changed = 1;
-  netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_JH_SETK;
+  nsys_netout_jsend_checkpoint_changed = 1;
+  nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] |= NSYS_SM_JH_SETK;
   check_seqnum_net = htons((unsigned short) (NSYS_RTPSEQ_LOMASK &
-					     netout_jsend_checkpoint_seqnum));
-  memcpy(&(netout_jsend_header[NSYS_SM_JH_LOC_CHECK]),
+					     nsys_netout_jsend_checkpoint_seqnum));
+  memcpy(&(nsys_netout_jsend_header[NSYS_SM_JH_LOC_CHECK]),
 	 &check_seqnum_net, sizeof(unsigned short));
 
 }
