@@ -55,12 +55,12 @@ void nsys_netout_rtcptime(void)
 /*              process received RTCP packet                    */
 /****************************************************************/
 
-source * nsys_netin_rtcp(unsigned char * packet, int len, 
+nsys_source * nsys_netin_rtcp(unsigned char * packet, int len, 
 		     struct sockaddr_in * ipaddr)
 
 {
   unsigned long ssrc, new_stamp, hiseq;
-  struct source * sptr = NULL;
+  struct nsys_source * sptr = NULL;
   int skip, overflow;
   unsigned short sect_len;
   int first = 0;
@@ -272,41 +272,41 @@ void nsys_netout_rtcp_initpackets(void)
   
   sdes_size += 4 - (sdes_size & 3);
 
-  if (!netout_rtcp_packet_bye)
+  if (!nsys_netout_rtcp_packet_bye)
     {
 
       /*********************/
       /* create BYE packet */
       /*********************/
 
-      netout_rtcp_len_bye = (NSYS_RTCPLEN_RREMPTY + sdes_size +
+      nsys_netout_rtcp_len_bye = (NSYS_RTCPLEN_RREMPTY + sdes_size +
 			     NSYS_RTCPLEN_BYE);
 
-      netout_rtcp_packet_bye = malloc(netout_rtcp_len_bye + 
+      nsys_netout_rtcp_packet_bye = malloc(nsys_netout_rtcp_len_bye + 
 				      NSYS_MD5_LENGTH + 1);
 
       /*********************/
       /* create RR packets */
       /*********************/
 
-      netout_rtcp_len_rrempty = NSYS_RTCPLEN_RREMPTY + sdes_size;
-      netout_rtcp_packet_rrempty = malloc(netout_rtcp_len_rrempty + 
+      nsys_netout_rtcp_len_rrempty = NSYS_RTCPLEN_RREMPTY + sdes_size;
+      nsys_netout_rtcp_packet_rrempty = malloc(nsys_netout_rtcp_len_rrempty + 
 					  NSYS_MD5_LENGTH + 1);
 
-      netout_rtcp_len_rr = NSYS_RTCPLEN_RR + sdes_size;
-      netout_rtcp_packet_rr = malloc(netout_rtcp_len_rr + 
+      nsys_netout_rtcp_len_rr = NSYS_RTCPLEN_RR + sdes_size;
+      nsys_netout_rtcp_packet_rr = malloc(nsys_netout_rtcp_len_rr + 
 				     NSYS_MD5_LENGTH + 1);
 	  
       /*********************/
       /* create SR packets */
       /*********************/
 
-      netout_rtcp_len_srempty = NSYS_RTCPLEN_SREMPTY + sdes_size;
-      netout_rtcp_packet_srempty = malloc(netout_rtcp_len_srempty + 
+      nsys_netout_rtcp_len_srempty = NSYS_RTCPLEN_SREMPTY + sdes_size;
+      nsys_netout_rtcp_packet_srempty = malloc(nsys_netout_rtcp_len_srempty + 
 					  NSYS_MD5_LENGTH + 1);
 
-      netout_rtcp_len_sr = NSYS_RTCPLEN_SR + sdes_size;
-      netout_rtcp_packet_sr = malloc(netout_rtcp_len_sr + 
+      nsys_netout_rtcp_len_sr = NSYS_RTCPLEN_SR + sdes_size;
+      nsys_netout_rtcp_packet_sr = malloc(nsys_netout_rtcp_len_sr + 
 				     NSYS_MD5_LENGTH + 1);
 
     }
@@ -315,40 +315,40 @@ void nsys_netout_rtcp_initpackets(void)
   /* initialize head of all RTCP packets */
   /***************************************/
 
-  nsys_netout_rtcp_initrr(netout_rtcp_packet_rrempty, NSYS_RTCPLEN_RREMPTY);
-  nsys_netout_rtcp_initrr(netout_rtcp_packet_rr, NSYS_RTCPLEN_RR);
+  nsys_netout_rtcp_initrr(nsys_netout_rtcp_packet_rrempty, NSYS_RTCPLEN_RREMPTY);
+  nsys_netout_rtcp_initrr(nsys_netout_rtcp_packet_rr, NSYS_RTCPLEN_RR);
   
-  nsys_netout_rtcp_initsr(netout_rtcp_packet_srempty, NSYS_RTCPLEN_SREMPTY);
-  nsys_netout_rtcp_initsr(netout_rtcp_packet_sr, NSYS_RTCPLEN_SR);
+  nsys_netout_rtcp_initsr(nsys_netout_rtcp_packet_srempty, NSYS_RTCPLEN_SREMPTY);
+  nsys_netout_rtcp_initsr(nsys_netout_rtcp_packet_sr, NSYS_RTCPLEN_SR);
   
-  nsys_netout_rtcp_initrr(netout_rtcp_packet_bye, NSYS_RTCPLEN_RREMPTY);
+  nsys_netout_rtcp_initrr(nsys_netout_rtcp_packet_bye, NSYS_RTCPLEN_RREMPTY);
   
   /***************************************/
   /* initialize SDES of all RTCP packets */
   /***************************************/
 
-  nsys_netout_rtcp_initsdes(&(netout_rtcp_packet_rrempty
+  nsys_netout_rtcp_initsdes(&(nsys_netout_rtcp_packet_rrempty
 			      [NSYS_RTCPLEN_RREMPTY]), sdes_size);
-  nsys_netout_rtcp_initsdes(&(netout_rtcp_packet_rr
+  nsys_netout_rtcp_initsdes(&(nsys_netout_rtcp_packet_rr
 			      [NSYS_RTCPLEN_RR]), sdes_size);
 
-  nsys_netout_rtcp_initsdes(&(netout_rtcp_packet_srempty
+  nsys_netout_rtcp_initsdes(&(nsys_netout_rtcp_packet_srempty
 			      [NSYS_RTCPLEN_SREMPTY]), sdes_size);
-  nsys_netout_rtcp_initsdes(&(netout_rtcp_packet_sr
+  nsys_netout_rtcp_initsdes(&(nsys_netout_rtcp_packet_sr
 			      [NSYS_RTCPLEN_SR]), sdes_size);
 
-  nsys_netout_rtcp_initsdes(&(netout_rtcp_packet_bye
+  nsys_netout_rtcp_initsdes(&(nsys_netout_rtcp_packet_bye
 			      [NSYS_RTCPLEN_RREMPTY]), sdes_size);
 
   /*******************************/
   /* initialize BYE packet, sign */
   /*******************************/
 
-  nsys_netout_rtcp_initbye(&(netout_rtcp_packet_bye
+  nsys_netout_rtcp_initbye(&(nsys_netout_rtcp_packet_bye
 			     [NSYS_RTCPLEN_RREMPTY + sdes_size]));
 
-  nsys_hmac_md5(netout_rtcp_packet_bye, netout_rtcp_len_bye, nsys_keydigest,
-		&(netout_rtcp_packet_bye[netout_rtcp_len_bye]));
+  nsys_hmac_md5(nsys_netout_rtcp_packet_bye, nsys_netout_rtcp_len_bye, nsys_keydigest,
+		&(nsys_netout_rtcp_packet_bye[nsys_netout_rtcp_len_bye]));
 
 }
 
@@ -359,7 +359,7 @@ void nsys_netout_rtcp_initpackets(void)
 int nsys_netin_clear_mset(unsigned char * buff, long * fill, long size)
 
 {
-  source s;
+  nsys_source s;
 
   if (!nsys_powerup_mset)
     return NSYS_JOURNAL_RECOVERED;
@@ -383,7 +383,7 @@ int nsys_netin_clear_mset(unsigned char * buff, long * fill, long size)
 int nsys_netout_excheck(void) 
 
 {
-  struct source * sptr;
+  struct nsys_source * sptr;
   int print_exit, rfd;
 
   if (nsys_rtcp_ex & (NSYS_RTCPEX_RTPSIP | NSYS_RTCPEX_RTCPSIP))
@@ -441,8 +441,8 @@ int nsys_netout_excheck(void)
   /*************************/
 
   if ((nsys_rtcp_ex & NSYS_RTCPEX_NULLROOT) == 0)
-    nsys_netout_rtcpsend(netout_rtcp_packet_bye, 
-			 netout_rtcp_len_bye + NSYS_RTPSIZE_DIGEST);
+    nsys_netout_rtcpsend(nsys_netout_rtcp_packet_bye, 
+			 nsys_netout_rtcp_len_bye + NSYS_RTPSIZE_DIGEST);
 
   /*****************/
   /* shut down SIP */
@@ -514,7 +514,7 @@ void nsys_netout_rtcpreport(void)
   unsigned long dead_ssrc;
   unsigned long expected, expected_this, received_this;
   long num_lost;
-  struct source * sptr;
+  struct nsys_source * sptr;
   struct sockaddr * addr;
   struct timeval now;
 
@@ -526,41 +526,41 @@ void nsys_netout_rtcpreport(void)
       nsys_sent_this = 0;
       
       offset = NSYS_RTCPLEN_SRHDR + NSYS_RTCPLEN_SENDER;
-      len_empty = netout_rtcp_len_srempty;
-      p_empty = netout_rtcp_packet_srempty;
-      len_full = netout_rtcp_len_sr;
-      p_full = netout_rtcp_packet_sr;
+      len_empty = nsys_netout_rtcp_len_srempty;
+      p_empty = nsys_netout_rtcp_packet_srempty;
+      len_full = nsys_netout_rtcp_len_sr;
+      p_full = nsys_netout_rtcp_packet_sr;
 
       gettimeofday(&now, 0);
 
-      *((unsigned long *) &(netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_NTPMSB])) =
+      *((unsigned long *) &(nsys_netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_NTPMSB])) =
 	htonl(0x83aa7e80 + now.tv_sec);
 
-      *((unsigned long *) &(netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_NTPLSB])) =
+      *((unsigned long *) &(nsys_netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_NTPLSB])) =
 	htonl((unsigned long) 
 	      (((((unsigned long)(now.tv_usec << 12))/15625) << 14))); 
 
-      *((unsigned long *) &(netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_TSTAMP])) =
+      *((unsigned long *) &(nsys_netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_TSTAMP])) =
 	htonl(nsys_netout_tstamp);
 
-      *((unsigned long *) &(netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_PACKET])) =
+      *((unsigned long *) &(nsys_netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_PACKET])) =
 	htonl(nsys_sent_packets);
 
-      *((unsigned long *) &(netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_OCTET])) =
+      *((unsigned long *) &(nsys_netout_rtcp_packet_sr[NSYS_RTCPLOC_SR_OCTET])) =
 	htonl(nsys_sent_octets);
 
-      memcpy(&(netout_rtcp_packet_srempty[NSYS_RTCPLEN_SRHDR]), 
-	     &(netout_rtcp_packet_sr[NSYS_RTCPLEN_SRHDR]), 
+      memcpy(&(nsys_netout_rtcp_packet_srempty[NSYS_RTCPLEN_SRHDR]), 
+	     &(nsys_netout_rtcp_packet_sr[NSYS_RTCPLEN_SRHDR]), 
 	     NSYS_RTCPLEN_SENDER);
     }
   else
     {
       offset = NSYS_RTCPLEN_RRHDR;
 
-      len_empty = netout_rtcp_len_rrempty;
-      p_empty = netout_rtcp_packet_rrempty;
-      len_full = netout_rtcp_len_rr;
-      p_full = netout_rtcp_packet_rr;
+      len_empty = nsys_netout_rtcp_len_rrempty;
+      p_empty = nsys_netout_rtcp_packet_rrempty;
+      len_full = nsys_netout_rtcp_len_rr;
+      p_full = nsys_netout_rtcp_packet_rr;
     }
 
   do 
@@ -679,7 +679,7 @@ void nsys_netout_rtcpsend(unsigned char * p, int len)
 {  
   int retry = 0;
   int alt = 0;
-  struct source * sptr;
+  struct nsys_source * sptr;
   struct sockaddr * addr;
 
   sptr = nsys_srcroot;
@@ -1129,8 +1129,8 @@ void nsys_netout_rtcp_initbye(unsigned char * p)
 void nsys_delete_ssrc(unsigned long ssrc, char * reason)
 
 {
-  struct source * sptr;
-  struct source * last;
+  struct nsys_source * sptr;
+  struct nsys_source * last;
   int mset, i;
   last = NULL;
   sptr = nsys_ssrc[ssrc & NSYS_HASHMASK];
@@ -1205,7 +1205,7 @@ void nsys_delete_ssrc(unsigned long ssrc, char * reason)
 
 #endif
 
-  memset(sptr, 0, sizeof(struct source));
+  memset(sptr, 0, sizeof(struct nsys_source));
   
   sptr->mset = mset;
   sptr->next = nsys_srcfree;
@@ -1219,10 +1219,10 @@ void nsys_delete_ssrc(unsigned long ssrc, char * reason)
 /*               harvest an unused ssrc slot                   */
 /***************************************************************/
 
-source * nsys_harvest_ssrc(int fd, struct sockaddr_in * ipaddr)
+nsys_source * nsys_harvest_ssrc(int fd, struct sockaddr_in * ipaddr)
 
 {
-  source * sptr, * oldptr;
+  nsys_source * sptr, * oldptr;
   unsigned long now, oldtime;
   int found = 0;
 
@@ -1279,7 +1279,7 @@ source * nsys_harvest_ssrc(int fd, struct sockaddr_in * ipaddr)
 /*   state update when an RTP/RTCP packet arrive too late      */
 /***************************************************************/
 
-void nsys_late_windowcheck(source * sptr, unsigned long tstamp)
+void nsys_late_windowcheck(nsys_source * sptr, unsigned long tstamp)
 
 {
   unsigned long tdiff;
@@ -1336,7 +1336,7 @@ void nsys_netin_rtcp_trunc(int sub)
 /*         initialize debug files for latenotes                */
 /***************************************************************/
 
-void nsys_netin_latenotes_open(source * sptr)
+void nsys_netin_latenotes_open(nsys_source * sptr)
 
 {
 
