@@ -37,8 +37,8 @@ int nsys_setup(int block)
 
 {
   struct hostent * myinfo;
-  struct source * newsrc;
-  struct netout_jrecv_state * newrecv;
+  struct nsys_source * newsrc;
+  struct nsys_netout_jrecv_state * newrecv;
   struct sockaddr_in iclient_addr; 
   struct timeval tv;
   unsigned char session_digest[NSYS_MD5_LENGTH];
@@ -152,16 +152,16 @@ int nsys_setup(int block)
   if (bad_netconfig)
     {
       if (nsys_find_clientip(nsys_clientip) == NULL)
-	NSYS_ERROR_RETURN("Machine IP number unknown.");
+	NSYS_ERROR_RETURN("Machine IP number unknown");
 
       if (!strcmp(nsys_clientip, "127.0.0.1"))
-	NSYS_ERROR_RETURN("Machine IP misconfiguration (loopback address).");
+	NSYS_ERROR_RETURN("Machine IP misconfiguration (loopback address)");
 
       if (!strcmp(nsys_clientip, "0.0.0.0"))
-	NSYS_ERROR_RETURN("Machine IP misconfiguration (0.0.0.0).");
+	NSYS_ERROR_RETURN("Machine IP misconfiguration (0.0.0.0)");
 
       if (!strcmp(nsys_clientip, "255.255.255.255"))
-	NSYS_ERROR_RETURN("Machine IP misconfiguration (broadcast address).");
+	NSYS_ERROR_RETURN("Machine IP misconfiguration (broadcast address)");
     }
 
   if (getlogin())
@@ -218,7 +218,7 @@ int nsys_setup(int block)
 
   for (i = NSYS_MSETS; i > 0; i--)
     {
-      newsrc = calloc(1, sizeof(struct source));
+      newsrc = calloc(1, sizeof(struct nsys_source));
       newsrc->mset = i;
       newsrc->next = nsys_srcfree;
       nsys_srcfree = newsrc;
@@ -226,7 +226,7 @@ int nsys_setup(int block)
 
   for (i = 0; i < NSYS_RECVCHAN*NSYS_MSETS; i++)
     {
-      newrecv = calloc(1, sizeof(struct netout_jrecv_state));
+      newrecv = calloc(1, sizeof(struct nsys_netout_jrecv_state));
       newrecv->next = nsys_recvfree;
       nsys_recvfree = newrecv;
     }
@@ -266,35 +266,35 @@ int nsys_setup(int block)
   /* setup sa-midi packetization */
   /*******************************/
 
-  netout_jsend_checkpoint_seqnum = nsys_netout_seqnum;
-  netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] = NSYS_SM_JH_SETA;
+  nsys_netout_jsend_checkpoint_seqnum = nsys_netout_seqnum;
+  nsys_netout_jsend_header[NSYS_SM_JH_LOC_FLAGS] = NSYS_SM_JH_SETA;
 
   for (i = 0; i < CSYS_MIDI_NUMCHAN; i++)
-    netout_jsend[i].chan = i;
+    nsys_netout_jsend[i].chan = i;
 
   nsys_netout_journal_changecheck();
 
   switch (nsys_feclevel) {
   case NSYS_SM_FEC_NONE:
   case NSYS_SM_FEC_NOGUARD:
-    netout_jsend_guard_ontime  = 0;
-    netout_jsend_guard_mintime = 0;
-    netout_jsend_guard_maxtime = 0;
+    nsys_netout_jsend_guard_ontime  = 0;
+    nsys_netout_jsend_guard_mintime = 0;
+    nsys_netout_jsend_guard_maxtime = 0;
     break;
   case NSYS_SM_FEC_MINIMAL:
-    netout_jsend_guard_ontime  = 0;
-    netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_MINTIME)/ACYCLE;
-    netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
+    nsys_netout_jsend_guard_ontime  = 0;
+    nsys_netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_MINTIME)/ACYCLE;
+    nsys_netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
     break;
   case NSYS_SM_FEC_STANDARD:
-    netout_jsend_guard_ontime  = 0;
-    netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_STDTIME)/ACYCLE;
-    netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
+    nsys_netout_jsend_guard_ontime  = 0;
+    nsys_netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_STDTIME)/ACYCLE;
+    nsys_netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
     break;
   case NSYS_SM_FEC_EXTRA:
-    netout_jsend_guard_ontime  = (ARATE*NSYS_SM_GUARD_ONTIME)/ACYCLE;
-    netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_STDTIME)/ACYCLE;
-    netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
+    nsys_netout_jsend_guard_ontime  = (ARATE*NSYS_SM_GUARD_ONTIME)/ACYCLE;
+    nsys_netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_STDTIME)/ACYCLE;
+    nsys_netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
     break;
   }
 
@@ -314,7 +314,7 @@ void nsys_shutdown(void)
 {  
 
 #if (NSYS_LATENOTES_DEBUG == NSYS_LATENOTES_DEBUG_ON)
-  struct source * sptr = nsys_srcroot;
+  struct nsys_source * sptr = nsys_srcroot;
 #endif
 
   nsys_warning(NSYS_WARN_STANDARD, "Shutdown in progress");
@@ -322,8 +322,8 @@ void nsys_shutdown(void)
   /* send RTCP BYE command to all listeners */
 
   if ((nsys_rtcp_ex & NSYS_RTCPEX_NULLROOT) == 0)
-    nsys_netout_rtcpsend(netout_rtcp_packet_bye, 
-			 netout_rtcp_len_bye + NSYS_RTPSIZE_DIGEST);
+    nsys_netout_rtcpsend(nsys_netout_rtcp_packet_bye, 
+			 nsys_netout_rtcp_len_bye + NSYS_RTPSIZE_DIGEST);
 
   /* send SIP BYE command to the SIP server */
 
@@ -362,10 +362,10 @@ void nsys_shutdown(void)
 /*              add new SSRC to send/receive list               */
 /****************************************************************/
 
-source * nsys_netin_addsrc(int fd, long ssrc, char * ip, unsigned short port)
+nsys_source * nsys_netin_addsrc(int fd, long ssrc, char * ip, unsigned short port)
 
 {
-  struct source * sptr;
+  struct nsys_source * sptr;
   struct sockaddr_in ipaddr;
 
   if (nsys_srcfree == NULL)
@@ -437,7 +437,7 @@ source * nsys_netin_addsrc(int fd, long ssrc, char * ip, unsigned short port)
 /*         updates RTCP info for a new RTP packet               */
 /****************************************************************/
 
-int nsys_netin_rtpstats(source * sptr, unsigned char * packet)
+int nsys_netin_rtpstats(nsys_source * sptr, unsigned char * packet)
 
 {
   unsigned long seq;
@@ -618,7 +618,7 @@ void nsys_warning(int level, char * message)
 /*             prints out status message for a source           */
 /****************************************************************/
 
-void nsys_status(source * sptr, char * message) 
+void nsys_status(nsys_source * sptr, char * message) 
 		
 {
   time_t now = time(NULL);
@@ -675,7 +675,7 @@ int nsys_netin_ptypevalid(unsigned char ptype)
 /*              fix payload for new RTP stream                  */
 /****************************************************************/
 
-void nsys_netin_ptypeset(struct source * sptr, unsigned char ptype)
+void nsys_netin_ptypeset(struct nsys_source * sptr, unsigned char ptype)
 
 {  
   int j;
@@ -694,19 +694,19 @@ void nsys_netin_ptypeset(struct source * sptr, unsigned char ptype)
 /*              return a new jrecv pointer                      */
 /****************************************************************/
 
-netout_jrecv_state * nsys_netin_newrecv(unsigned char chan)
+nsys_netout_jrecv_state * nsys_netin_newrecv(unsigned char chan)
 
 {
-  netout_jrecv_state * ret;
+  nsys_netout_jrecv_state * ret;
 
   if (nsys_recvfree)
     {
       ret = nsys_recvfree;
       nsys_recvfree = nsys_recvfree->next;
-      memset(ret, 0, sizeof(struct netout_jrecv_state));
+      memset(ret, 0, sizeof(struct nsys_netout_jrecv_state));
     }
   else
-    ret = calloc(1, sizeof(struct netout_jrecv_state));
+    ret = calloc(1, sizeof(struct nsys_netout_jrecv_state));
 
   ret->chan = chan;
   return ret;
@@ -719,13 +719,10 @@ netout_jrecv_state * nsys_netin_newrecv(unsigned char chan)
 char * nsys_find_clientip(char * ip)
      
 {
-
-#if (!defined(sun) && !defined(__sun__))  /* avoid Sys5/BSD issues */
-
-  char buf[32*sizeof(struct ifreq)];
+  char buf[64*sizeof(struct ifreq)];
   struct ifconf ifc;
   struct ifreq * ifr;
-  int s, n;
+  int s, n, incr;
 
   /* open a socket, get list of addresses */
   
@@ -742,11 +739,24 @@ char * nsys_find_clientip(char * ip)
     }
 
   /* look through addresses, return a useful one */
+  /* thanks to Jens-Uwe Mager for BSD 4.4 updates */
 
   ifr = ifc.ifc_req;
-  
-  for (n = ifc.ifc_len/sizeof(struct ifreq); --n >= 0; ifr++) 
+
+  for (n = 0; n < ifc.ifc_len; ifr = (struct ifreq *)(incr + (char *)ifr))
     {
+      incr = sizeof(struct ifreq);
+
+#if NSYS_IFCONF_VARLEN
+
+      incr -= sizeof(struct sockaddr);
+      incr += ((sizeof(struct sockaddr) > ifr->ifr_addr.sa_len) ?
+	       sizeof(struct sockaddr) : ifr->ifr_addr.sa_len);
+
+#endif
+
+      n += incr;
+
       if (ifr->ifr_addr.sa_family != AF_INET)
 	continue;
       
@@ -772,10 +782,8 @@ char * nsys_find_clientip(char * ip)
     }
 
   close(s);
-
-#endif
-
   return NULL;
 }
 
+
 /* end Network library -- RTP functions */
