@@ -258,12 +258,12 @@ void nsys_netin_invite(int fd, struct sockaddr_in * addr,
 
 {  
   struct sockaddr_in ** aptr;
-  struct source * sptr;
+  struct nsys_source * sptr;
   char line[NSYS_UDPMAXSIZE+1];
   char media[NSYS_UDPMAXSIZE+1];
   char sname[NSYS_BASE64_LENGTH];
   char tool[32] = "unknown";
-  struct payinfo * marray;
+  struct nsys_payinfo * marray;
   int mlen = 0;
   char cname[32];
   char dnsname[64];
@@ -408,7 +408,7 @@ void nsys_netin_invite(int fd, struct sockaddr_in * addr,
 	  
 	  sptr->siptime = sdp_time;
 	  nsys_netin_payset(sptr, marray, mlen);
-	  sptr->last_hiseq_ext = netout_jsend_checkpoint_seqnum;
+	  sptr->last_hiseq_ext = nsys_netout_jsend_checkpoint_seqnum;
 
 	  if (nsys_msessionmirror)
 	    nsys_rtcp_ex &= ~NSYS_RTCPEX_SRCDUPL;
@@ -1137,7 +1137,7 @@ int nsys_netin_siporigin(int fd, struct sockaddr_in * addr)
 /*              makes an array of media payloads                */
 /****************************************************************/
 
-int nsys_netin_make_marray(struct payinfo ** marray, char * media)
+int nsys_netin_make_marray(struct nsys_payinfo ** marray, char * media)
 
 {
   int size, i, len;
@@ -1158,7 +1158,7 @@ int nsys_netin_make_marray(struct payinfo ** marray, char * media)
   if (!size)
     return size;
 
- *marray = calloc(size, sizeof(struct payinfo));
+ *marray = calloc(size, sizeof(struct nsys_payinfo));
  cptr = media;
 
  for (i = 0; i < size; i++)
@@ -1177,7 +1177,7 @@ int nsys_netin_make_marray(struct payinfo ** marray, char * media)
 /*                 sets a media payloads                       */
 /****************************************************************/
 
-int nsys_netin_set_marray(char * line, struct payinfo marray[], int mlen)
+int nsys_netin_set_marray(char * line, struct nsys_payinfo marray[], int mlen)
 
 {
   unsigned short ptype;  /* sscanf needs a short, not a char */
@@ -1216,7 +1216,7 @@ int nsys_netin_set_marray(char * line, struct payinfo marray[], int mlen)
 /*             checks validity of payload ptype                 */
 /****************************************************************/
 
-int nsys_netin_payvalid(struct payinfo marray[], int mlen, int fd) 
+int nsys_netin_payvalid(struct nsys_payinfo marray[], int mlen, int fd) 
 			 
 
 {
@@ -1262,7 +1262,7 @@ int nsys_netin_payvalid(struct payinfo marray[], int mlen, int fd)
 /*             sets payload information in source               */
 /****************************************************************/
 
-void nsys_netin_payset(struct source * sptr, struct payinfo marray[],
+void nsys_netin_payset(struct nsys_source * sptr, struct nsys_payinfo marray[],
 		       int mlen) 
 			 
 
@@ -1288,7 +1288,7 @@ void nsys_netin_payset(struct source * sptr, struct payinfo marray[],
 int nsys_netin_noreplay(char * ip, unsigned short port, unsigned long sdp_time)
 
 {
-  struct source * sptr = nsys_srcroot;
+  struct nsys_source * sptr = nsys_srcroot;
   struct sockaddr_in ipaddr;
   int ret = 1;
 
