@@ -58,33 +58,27 @@ void optmain(void)
   /***************************/
 
   while (sptr != NULL)
-    {  
-      if ((sptr->score)||(sptr->ascore)||(sptr->dyn)||(sptr->startup)||
-	  (sptr->amidi)||(sptr->midi)|| 
-	  ((cmidi || session) && sptr->miditag)||csasl)
-	{
-
-	  currinputwidth = 1;           /* instr input width            */ 
-	  currinstrwidth = sptr->width; /* instr output width           */
-	  currinstancename = sptr->val; /* instr ASCII name             */
-	  curropcodeprefix = sptr->val; /*                              */
-	  currinstrument = sptr;        /* pointer to instr struct      */
-	  currinstance = NULL;          /* not an instance              */
-
-	  inrateupdate(sptr);           /* update rate and width        */
-	  widthupdate(sptr->defnode->down->
-		      next->next->next->next->next->next->next->next->down);
-
-	  globalclearcount();           /* clear global reference flags  */
-	  symtableinit(sptr);           /* init local reference flags    */ 
-	  tablerefer(sptr);             /* ref-count table expressions   */
-	  refercount(sptr);             /* reference count instr body    */
-	  tablepromote(sptr);           /* change local tables to global */
-	  duradd(sptr);                 /* if needed, add dur variable   */
-	  optlines(sptr);               /* do all optimizations          */
-	  globalrefer(sptr);            /* update global var ref counts  */
-	  mirrorupdate(sptr);           /* updates loca mirror ref count */
-	}
+    { 
+      currinputwidth = 1;           /* instr input width            */ 
+      currinstrwidth = sptr->width; /* instr output width           */
+      currinstancename = sptr->val; /* instr ASCII name             */
+      curropcodeprefix = sptr->val; /*                              */
+      currinstrument = sptr;        /* pointer to instr struct      */
+      currinstance = NULL;          /* not an instance              */
+      
+      inrateupdate(sptr);           /* update rate and width        */
+      widthupdate(sptr->defnode->down->
+		  next->next->next->next->next->next->next->next->down);
+      
+      globalclearcount();           /* clear global reference flags  */
+      symtableinit(sptr);           /* init local reference flags    */ 
+      tablerefer(sptr);             /* ref-count table expressions   */
+      refercount(sptr);             /* reference count instr body    */
+      tablepromote(sptr);           /* change local tables to global */
+      duradd(sptr);                 /* if needed, add dur variable   */
+      optlines(sptr);               /* do all optimizations          */
+      globalrefer(sptr);            /* update global var ref counts  */
+      mirrorupdate(sptr);           /* update local mirror ref count */
       sptr = sptr->next;
     }
 
@@ -176,8 +170,8 @@ void optglobalblock(void)
 	pvalptr = tptr->down->next->next->next->next->next->down;
       if (pvalptr)
 	{
-	  currinputwidth = 0;
-	  currinstrwidth = 1;
+	  currinputwidth = inchannels;
+	  currinstrwidth = outchannels;
 	  widthupdate(pvalptr);
 	  curropcoderate = ARATETYPE;
 	  currtreerate = UNKNOWN;
@@ -714,11 +708,9 @@ void globalrefer(sigsym * iptr)
   int skip;
 
   skip = !strcmp(iptr->val,"startup");
-  if (skip)
+  if (skip && reachableinstrexstart(iptr))
     {
-      if ((iptr->score + iptr->ascore + iptr->dyn + iptr->midi + iptr->amidi
-	   + ((cmidi || session) && iptr->miditag) + iptr->effects + csasl) > 0)
-	skip = 0;
+      skip = 0;
     }
   
   while (sptr != NULL)
