@@ -983,6 +983,13 @@ int nospeedtraps(tnode * tptr, int subrate)
 		   (!strcmp(tptr->val,"settune"))))
 		  return 0;
 
+	      /* don't optimize specialops, to maintain relative */
+	      /* ordering at the k-pass and a-pass. Probably too */
+	      /* conservative for opcalls, needed for oparrays.  */
+
+	      if (coreopcodespecial(tptr))
+		return 0;
+
 	      /* if rate-optimized sub-expressions of if and */
 	      /* while blocks are executed w/o guards, don't */
 	      /* optimize k- and i-rate core opcodes that    */
