@@ -22,7 +22,7 @@
 #ifndef _SFRONT_TREE_H
 #define _SFRONT_TREE_H 1
 
-#define IDSTRING "0.79 11/04/01"
+#define IDSTRING "0.85 10/13/02"
 
 #include <stdio.h>
 #include <math.h>
@@ -611,7 +611,7 @@ extern void * alloca(size_t);
 
 /* default SIP location */
 
-#define SIP_IP          "128.32.131.152"
+#define SIP_IP          "128.32.112.203"
 #define SIP_RTP_PORT    5060
 
 /* transposition for mirror session */
@@ -1142,6 +1142,7 @@ extern sigsym * locsymtable;
 extern sigsym * tlocsymtable;
 extern sigsym * globalsymtable;
 extern sigsym * instrnametable;
+extern sigsym * unusedinstrtable;
 extern sigsym * opcodenametable;
 extern sigsym * dinstrnametable;
 extern sigsym * busnametable;
@@ -1149,6 +1150,7 @@ extern sigsym * outputbus;
 extern sigsym * startupinstr;
 extern sigsym * instrpresets;
 extern sigsym * targetsymtable;
+extern sigsym * mpegtokens;
 
 extern char   * currinstancename;
 extern char   * curropcodeprefix;
@@ -1184,6 +1186,7 @@ extern int curropcalldepth;
 extern int maxoparraydepth;
 extern int curroparraydepth;
 extern int useshadowbus;
+extern int mpegtokencount;
 
 extern int ifrefdepth;
 extern int whilerefdepth;
@@ -1397,7 +1400,7 @@ extern int makeaintimedefault(int);
 
 /* from blocktree.c */
 
-extern void nextstateupdate(void);
+extern void nextstateupdate(int *);
 extern void blocktree(tnode *, int);
 
 /* from csrclib.c  */
@@ -1633,6 +1636,10 @@ extern char *   dupunderscore(char * val);
 extern tnode *  make_tnode(char *, int);
 extern long     make_long(tnode * tptr);
 extern int      largeinteger(char * s);
+extern int      reachableinstrexeff(sigsym *);
+extern int      reachableinstrexstart(sigsym *);
+extern int      reachableinstrexeffexstart(sigsym *);
+extern int      reachableinstr(sigsym *);
 
 /* from tokens.c */
 
