@@ -607,9 +607,11 @@ void makeglobalvars(void)
     fprintf(outfile,"/* first %i locations for MIDI */\n",i);
   fprintf(outfile,"#define GBL_STARTVAR %i\n",i);
 
-
   /* actually print out global signal variable consts */
 
+  currinputwidth = inchannels;
+  currinstrwidth = outchannels;
+
   sptr = globalsymtable;
   while (sptr != NULL)
     {
@@ -629,7 +631,7 @@ void makeglobalvars(void)
 	    fprintf(outfile,"#define CSYS_SASL_GBL_%s %i\n",sptr->val,i);
 	}
 
-      i = i + sptr->width;
+      i = i + truewidth(sptr->width);
       sptr = sptr->next;
     }
 
@@ -727,15 +729,6 @@ void makeglobaltabs(void)
 
 extern void instrdriversymbols(sigsym *, sigsym *, int i);
 
-
-/*****************************************************************/
-/*       this function is defined in the utility section.        */
-/*       it determines the true width of a symbol entry          */
-/*****************************************************************/
-
-extern int symbolwidth(int);
-
-
 /****************************************************************/
 /*   prints out variable symbols for non-effects instrs         */
 /****************************************************************/
@@ -751,9 +744,7 @@ void instrvars(int * maxvars)
   iptr = instrnametable;
   while (iptr != NULL)
     {
-      if ((iptr->score)||(iptr->ascore)||(iptr->dyn)||(iptr->startup)
-	  ||(iptr->midi)||(iptr->amidi)
-	  ||((cmidi || session) && iptr->miditag)|| csasl)
+      if (reachableinstrexeff(iptr))
 	{
 	  i = 0;
 	  currinputwidth = 1;
@@ -768,13 +759,12 @@ void instrvars(int * maxvars)
 		  fprintf(outfile,"#define %s_%s %i\n",iptr->val,sptr->val,i);
 		  if (csasl)
 		    instrdriversymbols(sptr, iptr, i);
-		  i += symbolwidth(sptr->width);
+		  i += truewidth(sptr->width);
 		}
 	      sptr = sptr->next;
 	    }
 	  for (k = 0; k < iptr->cref->ifstate; k++)
 	    fprintf(outfile,"#define %s__sym_if%i %i\n", iptr->val, k, i++);
-	  /* currinputwidth = 0; */   /* don't know why this was here ... */
 	  opcodedefines(iptr->defnode->optr,iptr->val,&i,&j);
 	  j = 1;
 	  fprintf(outfile,"#define %s_ENDVAR %i\n\n",iptr->val,i);
@@ -803,9 +793,7 @@ void instrtabs(int * maxtables)
   iptr = instrnametable;
   while (iptr != NULL)
     {
-      if ((iptr->score)||(iptr->ascore)||(iptr->dyn)||(iptr->startup)
-	  ||(iptr->midi)||(iptr->amidi)
-	  ||((cmidi || session) && iptr->miditag)|| csasl)
+      if (reachableinstrexeff(iptr))
 	{
 	  sptr = iptr->defnode->sptr;
 	  i = 0;
@@ -857,7 +845,7 @@ void effvars(int * maxvars)
 	      (sptr->tref->mirror == REQUIRED)) 
 	    {
 	      fprintf(outfile,"#define %s_%s %i\n",tptr->val,sptr->val,i);
-	      i += symbolwidth(sptr->width);
+	      i += truewidth(sptr->width);
 	    }
 	  sptr = sptr->next;
 	}
@@ -944,10 +932,8 @@ void makefexterns(void)
 
   sptr = instrnametable;
   while (sptr != NULL)
-    {
-      if ((sptr->score)||(sptr->ascore)||(sptr->dyn)||(sptr->startup)
-	  ||(sptr->midi)||(sptr->amidi)
-	  ||((cmidi || session) && sptr->miditag)||csasl)
+    { 
+      if (reachableinstrexeff(sptr))
 	{
 	  currinstance = NULL;
 	  currinstancename = sptr->val;
@@ -1225,6 +1211,23 @@ void controllibrary(void)
       fprintf(outfile,"#define CSYS_MIDI_CTOUCH   0xD0\n");
       fprintf(outfile,"#define CSYS_MIDI_WHEEL    0xE0\n");
       fprintf(outfile,"#define CSYS_MIDI_SYSTEM   0xF0\n\n");
+
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_SYSEX_START  0xF0\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_QFRAME       0xF1\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_SONG_PP      0xF2\n"); 
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_SONG_SELECT  0xF3\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_UNUSED1      0xF4\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_UNUSED2      0xF5\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_TUNE_REQUEST 0xF6\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_SYSEX_END    0xF7\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_CLOCK        0xF8\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_TICK         0xF9\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_START        0xFA\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_CONTINUE     0xFB\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_STOP         0xFC\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_UNUSED3      0xFD\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_SENSE        0xFE\n");
+      fprintf(outfile,"#define CSYS_MIDI_SYSTEM_RESET        0xFF\n\n");
       
       fprintf(outfile,"#define CSYS_MIDI_CC_BANKSELECT_MSB  0x00\n"); 
       fprintf(outfile,"#define CSYS_MIDI_CC_MODWHEEL_MSB    0x01\n");    
@@ -1685,23 +1688,6 @@ void instrdriversymbols(sigsym * sptr, sigsym * iptr, int i)
    }
 }
 
-/****************************************************************/
-/*  calculates width for symbols -- unclear if differences from */
-/*  truewidth() are important, so keeping it for now.           */
-/****************************************************************/
-
-int symbolwidth(int width)
-
-{
-
-  if ((width == INCHANNELSWIDTH) || (width == CHANNELSWIDTH))
-    return currinputwidth;
-  if (width == OUTCHANNELSWIDTH)
-    return currinstrwidth;
-  return width;
-
-}
-
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
 /* This function family prints the external function headers    */
 /*           needed later in the sa.c file.                     */
@@ -1738,14 +1724,14 @@ void printopexterns(tnode * tptr)
 		      "float %s(struct ninstr_types *);\n", newname);
 	      if (tptr->special)
 		fprintf(outfile,
-			"float %s_spec(struct ninstr_types *);\n",
+			"void %s_spec(struct ninstr_types *);\n",
 			newname);
 	    }
 	  else
 	    {
 	      fprintf(outfile,"float %s(void);\n", newname);
 	      if (tptr->special)
-		fprintf(outfile,"float %s_spec(void);\n", newname);
+		fprintf(outfile,"void %s_spec(void);\n", newname);
 	    }
 
 	  /* do constant oparray index syntax check */
@@ -1792,9 +1778,7 @@ void printpassexterns(void)
   sptr = instrnametable;
   while (sptr != NULL)
     {
-      if ((sptr->score)||(sptr->ascore)||(sptr->dyn)||(sptr->midi)
-	  ||(sptr->amidi)
-	  ||((cmidi || session) && sptr->miditag) || csasl)
+      if (reachableinstrexeffexstart(sptr))
 	{
 	  fprintf(outfile,"void %s_ipass(struct ninstr_types *);\n",sptr->val);
 	  fprintf(outfile,"void %s_kpass(struct ninstr_types *);\n",sptr->val);
@@ -1880,9 +1864,7 @@ void printsaoltables(int type)
   iptr = instrnametable;
   while (iptr != NULL)
     {
-      if ((iptr->score)||(iptr->ascore)||(iptr->dyn)||(iptr->startup)
-	  ||(iptr->midi)||(iptr->amidi)
-	  ||((cmidi || session) && iptr->miditag)|| csasl)
+      if (reachableinstrexeff(iptr))
 	{
 	  sptr = iptr->defnode->sptr;
 	  while (sptr != NULL)
@@ -2004,7 +1986,8 @@ void printcdriverstructs(void)
 
 {
   fprintf(outfile,"#define MAXCNOTES %i\n\n",MAXDNOTES);
-  fprintf(outfile,"#define CSYS_INSTRNUM %i\n\n", numinstrnames);
+  fprintf(outfile,"#define CSYS_INSTRNUM %i\n\n", 
+	  numinstrnames ? numinstrnames : 1);
 
   fprintf(outfile,"#define CSYS_IRATE 0\n");
   fprintf(outfile,"#define CSYS_KRATE 1\n");
@@ -2114,7 +2097,7 @@ void printcdriverglobalvars(void)
 {
   int numglobal = 0;
   int i, gcount, tbl;
-  sigsym * sptr, * bptr;
+  sigsym * sptr, * bptr, * token;
 
   sptr = globalsymtable;
   while (sptr)
@@ -2138,6 +2121,8 @@ void printcdriverglobalvars(void)
       fprintf(outfile,"csys_varstruct csys_global[CSYS_GLOBALNUM] = {\n");
       sptr = globalsymtable;
       gcount = numglobal;
+      currinputwidth = inchannels;
+      currinstrwidth = outchannels;
       tbl = 0;
       while (sptr)
 	{      
@@ -2161,7 +2146,13 @@ void printcdriverglobalvars(void)
 
 	      /* int token */
 
-	      fprintf(outfile,"%s, ", bitfile ? &(sptr->val[1]) : "-1");
+	      if (bitfile)
+		fprintf(outfile,"%s, ", &(sptr->val[1]));
+	      else
+		{
+		  token = getvsym(&mpegtokens, sptr->val);
+		  fprintf(outfile, "%i, ", token ? token->width : -1);
+		}
 
 	      /* int type and int tag*/
 
@@ -2178,13 +2169,13 @@ void printcdriverglobalvars(void)
 		break;
 	      }
 	      
-	      fprintf(outfile,"%i",sptr->width);  /* int width */
+	      fprintf(outfile,"%i", truewidth(sptr->width));
 	      if (--gcount)
 		fprintf(outfile,", \n");
 	      else
 		fprintf(outfile," };\n\n");
 	    }
-	  i = i + sptr->width;
+	  i = i + truewidth(sptr->width);
 	  if (sptr->vartype == TABLETYPE)
 	    tbl++;
 	  sptr = sptr->next;
@@ -2193,8 +2184,6 @@ void printcdriverglobalvars(void)
 }
 
 
-
-
 /****************************************************************/
 /*   computes position of labelled control variable in stack    */
 /****************************************************************/
@@ -2209,8 +2198,8 @@ int targetvarposition(sigsym * sptr, sigsym * vptr)
       if (sptr == vptr)
 	return ret;
       else
-	if (sptr->vartype != TMAPTYPE)
-	  ret += sptr->width;
+	if ((sptr->vartype != TMAPTYPE) && (sptr->tref->mirror == REQUIRED))
+	  ret += truewidth(sptr->width);
       sptr = sptr->next;
     }
 
@@ -2231,12 +2220,14 @@ void printcdrivertarget(void)
   int numtarget, numinstr;
   int i, tcount;
   int * instrindex, * varindex;
-  sigsym * sptr, * bptr, * iptr;
+  sigsym * sptr, * bptr, * iptr, * token;
 
   sptr = targetsymtable;
   numtarget = 0;
-  vmcheck(instrindex = (int *) calloc(numinstrnames, sizeof(int)));
-  vmcheck(varindex = (int *) calloc(numinstrnames, sizeof(int)));
+  vmcheck(instrindex = (int *) calloc(numinstrnames ? numinstrnames : 1,
+				      sizeof(int)));
+  vmcheck(varindex = (int *) calloc(numinstrnames ? numinstrnames : 1,
+				    sizeof(int)));
   while (sptr)
     {
       if (bitfile && bitsymin && (bptr = getvsym(&bitsymin,sptr->val)))
@@ -2252,6 +2243,9 @@ void printcdrivertarget(void)
 	      (bptr->kind == K_IMPORT))
 	    {
 	      instrindex[numinstr] = iptr->vol;
+
+	      currinputwidth = 1;
+	      currinstrwidth = iptr->width;
 	      varindex[numinstr] = targetvarposition(iptr->defnode->sptr,
 						     bptr);
 	      numinstr++;
@@ -2307,8 +2301,14 @@ void printcdrivertarget(void)
 	  fprintf(outfile,"\"%s\", ",name);
 
 	  /* int token */
-
-	  fprintf(outfile,"%s, ", bitfile ? &(sptr->val[1]) : "-1");
+	  
+	  if (bitfile)
+	    fprintf(outfile,"%s, ", &(sptr->val[1]));
+	  else
+	    {
+	      token = getvsym(&mpegtokens, sptr->val);
+	      fprintf(outfile, "%i, ", token ? token->width : -1);
+	    }
 
 	  /* int numinstr */
 
@@ -2342,7 +2342,7 @@ void printcdrivertarget(void)
 void printcdriverlabels(void)
 
 {
-  sigsym * sptr, * bptr, * iptr;
+  sigsym * sptr, * bptr, * iptr, * token;
   tnode * tptr;
   int found, totlabels;
 
@@ -2372,7 +2372,13 @@ void printcdriverlabels(void)
 
 	  /* int token */
 
-	  fprintf(outfile,"%s, ", bitfile ? &(sptr->val[1]) : "-1");
+	  if (bitfile)
+	    fprintf(outfile,"%s, ", &(sptr->val[1]));
+	  else
+	    {
+	      token = getvsym(&mpegtokens, sptr->val);
+	      fprintf(outfile, "%i, ", token ? token->width : -1);
+	    }
 
 	  iptr = instrnametable;
 	  while (iptr)
@@ -2456,7 +2462,7 @@ void printcdriverpresets(void)
 void printcdriversamples(void)
 
 {
-  sigsym * sptr, * bptr;
+  sigsym * sptr, * bptr, * token;
   char * name;
   int i;
 
@@ -2485,7 +2491,13 @@ void printcdriversamples(void)
 
 	  /* int token */
 
-	  fprintf(outfile, "%s, ",&(sptr->val[1])); 
+	  if (bitfile)
+	    fprintf(outfile,"%s, ", &(sptr->val[1]));
+	  else
+	    {
+	      token = getvsym(&mpegtokens, sptr->val);
+	      fprintf(outfile, "%i, ", token ? token->width : -1);
+	    }
 
 	  /* char * name */
 
@@ -2518,7 +2530,7 @@ void printcdrivervars(sigsym * instr)
 
 {
 
-  sigsym * sptr, * bptr;
+  sigsym * sptr, * bptr, * token;
   int numvars, i, comma;
   char * name, * varname;
 
@@ -2545,9 +2557,11 @@ void printcdrivervars(sigsym * instr)
     {
       fprintf(outfile,"csys_varstruct csys_%s_vars[CSYS_%s_VARNUM] = {\n",
 	      name, name);
+
       comma = i = 0;
-      currinputwidth = 1;              /* makes dummy location */
+      currinputwidth = 1;              
       currinstrwidth = instr->width;
+
       sptr = instr->defnode->sptr;
 
       while (sptr)
@@ -2565,7 +2579,10 @@ void printcdrivervars(sigsym * instr)
 
 	      /* int index */
 
-	      fprintf(outfile,"%i, ", i);
+	      if (sptr->tref->mirror == REQUIRED)
+		fprintf(outfile,"%i, ",sptr->vol);  
+	      else
+		fprintf(outfile, "-1, ");
 
 	      /* char * name */
 
@@ -2573,7 +2590,13 @@ void printcdrivervars(sigsym * instr)
 
 	      /* int token */
 
-	      fprintf(outfile,"%s, ", bitfile ? &(sptr->val[1]) : "-1");
+	      if (bitfile)
+		fprintf(outfile,"%s, ", &(sptr->val[1]));
+	      else
+		{
+		  token = getvsym(&mpegtokens, sptr->val);
+		  fprintf(outfile, "%i, ", token ? token->width : -1);
+		}
 
 	      /* int type */
 
@@ -2625,7 +2648,7 @@ void printcdrivervars(sigsym * instr)
 
 	    }
 
-	  if (sptr->vartype != TMAPTYPE)
+	  if ((sptr->vartype != TMAPTYPE) && (sptr->tref->mirror == REQUIRED))
 	    i += truewidth(sptr->width);
 
 	  sptr = sptr->next;
@@ -2642,7 +2665,7 @@ void printcdriverinstr(sigsym * sptr)
 
 {
   char * name;
-  sigsym * bptr;
+  sigsym * bptr, * token;
   int status;
 
   if (sptr->vol)
@@ -2656,13 +2679,19 @@ void printcdriverinstr(sigsym * sptr)
   /* int index, char * name */
 
   fprintf(outfile,"%i, \"%s\",",sptr->vol, name);  
-    
+      
   /* int token */
 
-  fprintf(outfile,"%s, ", bitfile && !(sptr->startup) ?
-	  &(sptr->val[1]) : "-1");
+  if (bitfile)
+    fprintf(outfile,"%s, ", !(sptr->startup) ? &(sptr->val[1]) : "-1");
+  else
+    {
+      token = getvsym(&mpegtokens, sptr->val);
+      fprintf(outfile, "%i, ", token ? token->width : -1);
+    }
 
   /* numvars, * vars */
+
   fprintf(outfile,"CSYS_%s_VARNUM, &(csys_%s_vars[0]),",
 	  name, name);
 
@@ -2865,7 +2894,7 @@ void printcdriversend(void)
 	  iptr = tptr->down->next->next->next->next->next->next->down;
 	  while (iptr)
 	    {
-	      if (iptr->ttype == S_IDENT)
+	      if (iptr->ttype == S_NAME)
 		j++;
 	      iptr = iptr->next;
 	    }
@@ -2876,9 +2905,9 @@ void printcdriversend(void)
 	  iptr = tptr->down->next->next->next->next->next->next->down;
 	  while (iptr)
 	    {
-	      if (iptr->ttype == S_IDENT)
+	      if (iptr->ttype == S_NAME)
 		{
-		  fprintf(outfile," %i",tptr->sptr->vol);
+		  fprintf(outfile," %i", iptr->sptr->vol);
 		  if (iptr->next)
 		    fprintf(outfile,",");
 		  else
@@ -3288,6 +3317,53 @@ void printsaslinit(char * name)
 
 }
 
+/****************************************************************/
+/*      prints cs declarations for table and variable size      */
+/****************************************************************/
+
+void printsaslsizes(void)
+
+{ 
+  int i;
+  sigsym * iptr;
+
+  fprintf(outfile,"int csys_instrtablesize[CSYS_MAXSASLINSTR] = {\n");
+
+  iptr = instrnametable;
+  i = 0;
+
+  while (iptr != NULL)
+    {
+      fprintf(outfile,"%s_ENDTBL%s",iptr->val,
+	      iptr->next ? "," : "};\n\n");
+
+      iptr = iptr->next;
+      if ((i++ == 4) && iptr)
+	{
+	  fprintf(outfile,"\n");
+	  i = 0;
+	}
+    }
+
+  fprintf(outfile,"int csys_instrvarsize[CSYS_MAXSASLINSTR] = {\n");
+
+  iptr = instrnametable;
+  i = 0;
+
+  while (iptr != NULL)
+    {
+      fprintf(outfile,"%s_ENDVAR%s",iptr->val,
+	      iptr->next ? "," : "};\n\n");
+
+      iptr = iptr->next;
+      if ((i++ == 4) && iptr)
+	{
+	  fprintf(outfile,"\n");
+	  i = 0;
+	}
+    }
+
+}
 
 
 /****************************************************************/
@@ -3332,6 +3408,7 @@ void printcdriverlists(int * instrnum)
       fprintf(outfile,"#define CSYS_SASL_NOINSTR %i\n",*instrnum);
       fprintf(outfile,"#define CSYS_SASL_MAXCONTROL %i\n",MAXDCONTROL);
       fprintf(outfile,"#define CSYS_SASL_MAXTABLES %i\n\n",MAXDTABLES);
+      printsaslsizes();
       printsaslinit("first");
       printsaslinit("last");
       printsaslinit("end");
