@@ -319,6 +319,7 @@ void wavegeneratorvar(sigsym * sptr)
     if (!(strcmp(ident->val,"cubicseg")))
       {
 	i = 1; j = 0;
+	z[lc++]="float %2$s_xf;";
 	z[lc++]="float %2$s_Q;";
 	z[lc++]="float %2$s_R;";
 	z[lc++]="float %2$s_S;";
@@ -616,6 +617,7 @@ void wavegeneratorvar(sigsym * sptr)
       }
     if (!(strcmp(ident->val,"spline")))
       {
+	z[lc++]="float %2$s_xf;";
 	z[lc++]="float %2$s_Q;";
 	z[lc++]="float %2$s_R;";
 	z[lc++]="float %2$s_S;";
@@ -896,6 +898,9 @@ void createwavetable(sigsym * ident, char * prefix, int mode)
 	z[lc++]= "while (i >= 0)";
 	z[lc++]= "{";
 	z[lc++]= "  NT(%1$s).t[i] = 0.0F;";
+
+	mz(lc); sprintf(z[lc++], "  %s_xf = i;", lname);
+
 	while (j >= 1)
 	  {
 	    mz(lc); 
@@ -908,9 +913,13 @@ void createwavetable(sigsym * ident, char * prefix, int mode)
 	    "  if ((i >= %s_infl%i) && (i < %s_infl%i) )",
 		   lname,j,lname,j+1);
 	    mz(lc); sprintf(z[lc++],
-            "    NT(%s_%s).t[i] =  i*i*i*%s_a%i+i*i*%s_b%i+i*%s_c%i+%s_d%i;",
-	    prefix,ident->val,lname,j,lname,j,lname,j,
-			    lname,j);
+			    "    NT(%s_%s).t[i] =  %s_xf*%s_xf*%s_xf*%s_a%i + "
+			    "%s_xf*%s_xf*%s_b%i + %s_xf*%s_c%i + %s_d%i;",
+			    prefix,ident->val, 
+			    lname, lname, lname, lname,j,
+			    lname, lname, lname, j,
+			    lname, lname, j,
+			    lname, j);
 
 	    j--;
 	  }
@@ -1244,6 +1253,9 @@ void createwavetable(sigsym * ident, char * prefix, int mode)
 	z[lc++]= "while (i >= 0)";
 	z[lc++]= "{";
 	z[lc++]= "  NT(%1$s).t[i] = 0.0F;";
+
+	mz(lc); sprintf(z[lc++], "  %s_xf = i;", lname);
+	    
 	while (j >= 1)
 	  {
 	    mz(lc);
@@ -1256,8 +1268,12 @@ void createwavetable(sigsym * ident, char * prefix, int mode)
 		 "  if ((i >= %s_x%i) && (i < %s_x%i) && (%s_x%i != %s_x%i))",
 		      lname,j,lname,j+1,lname,j,lname,j+1);
 	    mz(lc); sprintf(z[lc++],
-            "    NT(%s_%s).t[i] =  i*i*i*%s_a%i+i*i*%s_b%i+i*%s_c%i+%s_d%i;",
-	    prefix,ident->val,lname,j,lname,j,lname,j,
+			    "    NT(%s_%s).t[i] =  %s_xf*%s_xf*%s_xf*%s_a%i + " 
+			    "%s_xf*%s_xf*%s_b%i + %s_xf*%s_c%i + %s_d%i;",
+			    
+			    prefix,ident->val, lname, lname, lname, lname, j,
+			    lname, lname, lname,j,
+			    lname, lname,j,
 			    lname,j);
 
 	    j--;
@@ -2349,9 +2365,6 @@ void tablepreamble(sigsym * ident, char * prefix, int mode, int action)
 void wavevarinitcheck(tnode * tptr)
 
 {
-
-  currinputwidth = 0;
-  currinstrwidth = 1;
   widthupdate(tptr);
   if (truewidth(tptr->width) != 1)
     {
@@ -2499,7 +2512,7 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 		      prefix,ident->val, prefix, ident->val, size);
 
       mz(lc); sprintf(z[lc++], "NT(%s_%s).t = (float *)(calloc(%li, %i));",
-		      prefix, ident->val, size + 1, sizeof(float));
+		      prefix, ident->val, size + 1, (int)sizeof(float));
 
       mz(lc); sprintf(z[lc++], "NT(%s_%s).dmult = %eF;", prefix, ident->val,
 		      (double)(((1.0F/srate)*(sinfo->srate))/size));
